"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGridLayout(QLayout):
    """
    https://doc.qt.io/qt-6/qgridlayout.html

    **Detailed Description**

    QGridLayout takes the space made available to it (by its parent layout or by
    the **parentWidget** ()), divides it up into rows and columns, and puts each
    widget it manages into the correct cell.

    Columns and rows behave identically; we will discuss columns, but there are
    equivalent functions for rows.

    Each column has a minimum width and a stretch factor. The minimum width is
    the greatest of that set using **setColumnMinimumWidth** () and the minimum
    width of each widget in that column. The stretch factor is set using
    **setColumnStretch** () and determines how much of the available space the
    column will get over and above its necessary minimum.

    Normally, each managed widget or layout is put into a cell of its own using
    **addWidget** (). It is also possible for a widget to occupy multiple cells
    using the row and column spanning overloads of **addItem** () and
    **addWidget** (). If you do this, QGridLayout will guess how to distribute
    the size over the columns/rows (based on the stretch factors).

    To remove a widget from a layout, call **removeWidget** (). Calling
    **QWidget::hide** () on a widget also effectively removes the widget from
    the layout until **QWidget::show** () is called.

    This illustration shows a fragment of a dialog with a five-column, three-row
    grid (the grid is shown overlaid in magenta):

    ![A grid layout](images/qgridlayout.png)

    Columns 0, 2 and 4 in this dialog fragment are made up of a **QLabel** , a
    **QLineEdit** , and a QListBox. Columns 1 and 3 are placeholders made with
    **setColumnMinimumWidth** (). Row 0 consists of three **QLabel**  objects,
    row 1 of three **QLineEdit**  objects and row 2 of three QListBox objects.
    We used placeholder columns (1 and 3) to get the right amount of space
    between the columns.

    Note that the columns and rows are not equally wide or tall. If you want two
    columns to have the same width, you must set their minimum widths and
    stretch factors to be the same yourself. You do this using
    **setColumnMinimumWidth** () and **setColumnStretch** ().

    If the QGridLayout is not the top-level layout (i.e. does not manage all of
    the widget's area and children), you must add it to its parent layout when
    you create it, but before you do anything with it. The normal way to add a
    layout is by calling **addLayout** () on the parent layout.

    Once you have added your layout you can start putting widgets and other
    layouts into the cells of your grid layout using **addWidget** (),
    **addItem** (), and **addLayout** ().

    QGridLayout also includes two margin widths: the **contents margin**  and
    the **spacing** (). The contents margin is the width of the reserved space
    along each of the QGridLayout's four sides. The **spacing** () is the width
    of the automatically allocated spacing between neighboring boxes.

    The default contents margin values are provided by the **style** . The
    default value Qt styles specify is 9 for child widgets and 11 for windows.
    The spacing defaults to the same as the margin width for a top-level layout,
    or to the same as the parent layout.

    **See also** **QBoxLayout** , **QStackedLayout** , **Layout Management** ,
    and **Basic Layouts Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#QGridLayout

        **QGridLayout::QGridLayout(QWidget * parent = nullptr)**

        Constructs a new QGridLayout with parent widget, **parent**. The layout
        has one row and one column initially, and will expand when new items are
        inserted.

        The layout is set directly as the top-level layout for **parent**. There
        can be only one top-level layout for a widget. It is returned by
        **QWidget::layout** ().

        If **parent** is `nullptr`, then you must insert this grid layout into
        another layout, or set it as a widget's layout using
        **QWidget::setLayout** ().

        **See also** **QWidget::setLayout** ().
        """
        ...

    def itemAtPosition(self, row: int, column: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#itemAtPosition

        **QLayoutItem *QGridLayout::itemAtPosition(int row , int column )
        const**

        Returns the layout item that occupies cell ( **row** , **column** ), or
        `nullptr` if the cell is empty.

        **See also** **getItemPosition** () and **indexOf** ().
        """
        ...

    def spacing(self) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#spacing

        **[override virtual] int QGridLayout::spacing() const**

        Reimplements an access function for property: **QLayout::spacing** .

        If the vertical spacing is equal to the horizontal spacing, this
        function returns that value; otherwise it return -1.

        **See also** **setSpacing** (), **verticalSpacing** (), and
        **horizontalSpacing** ().
        """
        ...

    def setSpacing(self, spacing: int) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#setSpacing

        **[override virtual] void QGridLayout::setSpacing(int spacing )**

        Reimplements an access function for property: **QLayout::spacing** .

        This function sets both the vertical and horizontal spacing to
        **spacing**.

        **See also** **spacing** (), **setVerticalSpacing** (), and
        **setHorizontalSpacing** ().
        """
        ...

    def verticalSpacing(self) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#verticalSpacing-prop

        **verticalSpacing : int**

        This property holds the spacing between widgets that are laid out on top
        of each other

        If no value is explicitly set, the layout's vertical spacing is
        inherited from the parent layout, or from the style settings for the
        parent widget.

        **Access functions:**

        int **verticalSpacing** () const
        void **setVerticalSpacing** (int
        **spacing** )

        **See also** **horizontalSpacing** , **QStyle::pixelMetric** (), and
        **PM_LayoutHorizontalSpacing** .

        **Member Function Documentation**
        """
        ...

    def setVerticalSpacing(self, spacing: int) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#verticalSpacing-prop

        **verticalSpacing : int**

        This property holds the spacing between widgets that are laid out on top
        of each other

        If no value is explicitly set, the layout's vertical spacing is
        inherited from the parent layout, or from the style settings for the
        parent widget.

        **Access functions:**

        int **verticalSpacing** () const
        void **setVerticalSpacing** (int
        **spacing** )

        **See also** **horizontalSpacing** , **QStyle::pixelMetric** (), and
        **PM_LayoutHorizontalSpacing** .

        **Member Function Documentation**
        """
        ...

    def horizontalSpacing(self) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#horizontalSpacing-prop

        **horizontalSpacing : int**

        This property holds the spacing between widgets that are laid out side
        by side

        If no value is explicitly set, the layout's horizontal spacing is
        inherited from the parent layout, or from the style settings for the
        parent widget.

        **Access functions:**

        int **horizontalSpacing** () const
        void **setHorizontalSpacing** (int
        **spacing** )

        **See also** **verticalSpacing** , **QStyle::pixelMetric** (), and
        **PM_LayoutHorizontalSpacing** .
        """
        ...

    def setHorizontalSpacing(self, spacing: int) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#horizontalSpacing-prop

        **horizontalSpacing : int**

        This property holds the spacing between widgets that are laid out side
        by side

        If no value is explicitly set, the layout's horizontal spacing is
        inherited from the parent layout, or from the style settings for the
        parent widget.

        **Access functions:**

        int **horizontalSpacing** () const
        void **setHorizontalSpacing** (int
        **spacing** )

        **See also** **verticalSpacing** , **QStyle::pixelMetric** (), and
        **PM_LayoutHorizontalSpacing** .
        """
        ...

    def getItemPosition(self, idx: int) -> typing.Tuple[int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#getItemPosition

        **void QGridLayout::getItemPosition(int index , int * row , int * column
        , int * rowSpan , int * columnSpan ) const**

        Returns the position information of the item with the given **index**.

        The variables passed as **row** and **column** are updated with the
        position of the item in the layout, and the **rowSpan** and
        **columnSpan** variables are updated with the vertical and horizontal
        spans of the item.

        **See also** **itemAtPosition** () and **itemAt** ().
        """
        ...

    def setDefaultPositioning(self, n: int, orient: QtCore.Qt.Orientation) -> None:
        ...

    @typing.overload
    def addItem(
        self,
        item: QLayoutItem,
        row: int,
        column: int,
        rowSpan: int = ...,
        columnSpan: int = ...,
        alignment: QtCore.Qt.AlignmentFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#addItem

        **void QGridLayout::addItem(QLayoutItem * item , int row , int column ,
        int rowSpan = 1, int columnSpan = 1, Qt::Alignment alignment =
        Qt::Alignment())**

        Adds **item** at position **row** , **column** , spanning **rowSpan**
        rows and **columnSpan** columns, and aligns it according to
        **alignment**. If **rowSpan** and/or **columnSpan** is -1, then the item
        will extend to the bottom and/or right edge, respectively. The layout
        takes ownership of the **item**.

        **Warning:** Do not use this function to add child layouts or child
        widget items. Use **addLayout** () or **addWidget** () instead.
        """
        ...

    @typing.overload
    def addItem(self, a0: QLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#addItem-1

        **[override virtual protected] void QGridLayout::addItem(QLayoutItem *
        item )**

        Reimplements: **QLayout::addItem** (QLayoutItem *item).
        """
        ...

    def setGeometry(self, a0: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#setGeometry

        **[override virtual] void QGridLayout::setGeometry(const QRect & rect
        )**

        Reimplements: **QLayout::setGeometry** (const QRect &r).
        """
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#count

        **[override virtual] int QGridLayout::count() const**

        Reimplements: **QLayout::count() const** .
        """
        ...

    def takeAt(self, a0: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#takeAt

        **[override virtual] QLayoutItem *QGridLayout::takeAt(int index )**

        Reimplements: **QLayout::takeAt** (int index).
        """
        ...

    def itemAt(self, a0: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#itemAt

        **[override virtual] QLayoutItem *QGridLayout::itemAt(int index )
        const**

        Reimplements: **QLayout::itemAt(int index) const** .
        """
        ...

    def originCorner(self) -> QtCore.Qt.Corner:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#originCorner

        **Qt::Corner QGridLayout::originCorner() const**

        Returns the corner that's used for the grid's origin, i.e. for position
        (0, 0).

        **See also** **setOriginCorner** ().
        """
        ...

    def setOriginCorner(self, a0: QtCore.Qt.Corner) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#setOriginCorner

        **void QGridLayout::setOriginCorner(Qt::Corner corner )**

        Sets the grid's origin corner, i.e. position (0, 0), to **corner**.

        **See also** **originCorner** ().
        """
        ...

    @typing.overload
    def addLayout(
        self,
        a0: QLayout,
        row: int,
        column: int,
        alignment: QtCore.Qt.AlignmentFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#addLayout

        **void QGridLayout::addLayout(QLayout * layout , int row , int column ,
        Qt::Alignment alignment = Qt::Alignment())**

        Places the **layout** at position ( **row** , **column** ) in the grid.
        The top-left position is (0, 0).

        The alignment is specified by **alignment**. The default alignment is 0,
        which means that the widget fills the entire cell.

        A non-zero alignment indicates that the layout should not grow to fill
        the available space but should be sized according to **sizeHint** ().

        **layout** becomes a child of the grid layout.
        """
        ...

    @typing.overload
    def addLayout(
        self,
        a0: QLayout,
        row: int,
        column: int,
        rowSpan: int,
        columnSpan: int,
        alignment: QtCore.Qt.AlignmentFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#addLayout-1

        **void QGridLayout::addLayout(QLayout * layout , int row , int column ,
        int rowSpan , int columnSpan , Qt::Alignment alignment =
        Qt::Alignment())**

        This is an overloaded function.

        This version adds the layout **layout** to the cell grid, spanning
        multiple rows/columns. The cell will start at **row** , **column**
        spanning **rowSpan** rows and **columnSpan** columns.

        If **rowSpan** and/or **columnSpan** is -1, then the layout will extend
        to the bottom and/or right edge, respectively.
        """
        ...

    @typing.overload
    def addWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#addWidget-1

        **void QGridLayout::addWidget(QWidget * widget , int row , int column ,
        Qt::Alignment alignment = Qt::Alignment())**

        Adds the given **widget** to the cell grid at **row** , **column**. The
        top-left position is (0, 0) by default.

        The alignment is specified by **alignment**. The default alignment is 0,
        which means that the widget fills the entire cell.
        """
        ...

    @typing.overload
    def addWidget(
        self,
        a0: QWidget,
        row: int,
        column: int,
        alignment: QtCore.Qt.AlignmentFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#addWidget-2

        **void QGridLayout::addWidget(QWidget * widget , int fromRow , int
        fromColumn , int rowSpan , int columnSpan , Qt::Alignment alignment =
        Qt::Alignment())**

        This is an overloaded function.

        This version adds the given **widget** to the cell grid, spanning
        multiple rows/columns. The cell will start at **fromRow** ,
        **fromColumn** spanning **rowSpan** rows and **columnSpan** columns. The
        **widget** will have the given **alignment**.

        If **rowSpan** and/or **columnSpan** is -1, then the widget will extend
        to the bottom and/or right edge, respectively.
        """
        ...

    @typing.overload
    def addWidget(
        self,
        a0: QWidget,
        row: int,
        column: int,
        rowSpan: int,
        columnSpan: int,
        alignment: QtCore.Qt.AlignmentFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#addWidget-1

        **void QGridLayout::addWidget(QWidget * widget , int row , int column ,
        Qt::Alignment alignment = Qt::Alignment())**

        Adds the given **widget** to the cell grid at **row** , **column**. The
        top-left position is (0, 0) by default.

        The alignment is specified by **alignment**. The default alignment is 0,
        which means that the widget fills the entire cell.
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#invalidate

        **[override virtual] void QGridLayout::invalidate()**

        Reimplements: **QLayout::invalidate** ().
        """
        ...

    def expandingDirections(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#expandingDirections

        **[override virtual] Qt::Orientations QGridLayout::expandingDirections()
        const**

        Reimplements: **QLayout::expandingDirections() const** .
        """
        ...

    def minimumHeightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#minimumHeightForWidth

        **[override virtual] int QGridLayout::minimumHeightForWidth(int w )
        const**

        Reimplements: **QLayoutItem::minimumHeightForWidth(int w) const** .
        """
        ...

    def heightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#heightForWidth

        **[override virtual] int QGridLayout::heightForWidth(int w ) const**

        Reimplements: **QLayoutItem::heightForWidth(int) const** .
        """
        ...

    def hasHeightForWidth(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#hasHeightForWidth

        **[override virtual] bool QGridLayout::hasHeightForWidth() const**

        Reimplements: **QLayoutItem::hasHeightForWidth() const** .
        """
        ...

    def cellRect(self, row: int, column: int) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#cellRect

        **QRect QGridLayout::cellRect(int row , int column ) const**

        Returns the geometry of the cell with row **row** and column **column**
        in the grid. Returns an invalid rectangle if **row** or **column** is
        outside the grid.

        **Warning:** in the current version of Qt this function does not return
        valid results until **setGeometry** () has been called, i.e. after the
        **parentWidget** () is visible.
        """
        ...

    def rowCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#rowCount

        **int QGridLayout::rowCount() const**

        Returns the number of rows in this grid.
        """
        ...

    def columnCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#columnCount

        **int QGridLayout::columnCount() const**

        Returns the number of columns in this grid.
        """
        ...

    def columnMinimumWidth(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#columnMinimumWidth

        **int QGridLayout::columnMinimumWidth(int column ) const**

        Returns the column spacing for column **column**.

        **See also** **setColumnMinimumWidth** ().
        """
        ...

    def rowMinimumHeight(self, row: int) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#rowMinimumHeight

        **int QGridLayout::rowMinimumHeight(int row ) const**

        Returns the minimum width set for row **row**.

        **See also** **setRowMinimumHeight** ().
        """
        ...

    def setColumnMinimumWidth(self, column: int, minSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#setColumnMinimumWidth

        **void QGridLayout::setColumnMinimumWidth(int column , int minSize )**

        Sets the minimum width of column **column** to **minSize** pixels.

        **See also** **columnMinimumWidth** () and **setRowMinimumHeight** ().
        """
        ...

    def setRowMinimumHeight(self, row: int, minSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#setRowMinimumHeight

        **void QGridLayout::setRowMinimumHeight(int row , int minSize )**

        Sets the minimum height of row **row** to **minSize** pixels.

        **See also** **rowMinimumHeight** () and **setColumnMinimumWidth** ().
        """
        ...

    def columnStretch(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#columnStretch

        **int QGridLayout::columnStretch(int column ) const**

        Returns the stretch factor for column **column**.

        **See also** **setColumnStretch** ().
        """
        ...

    def rowStretch(self, row: int) -> int:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#rowStretch

        **int QGridLayout::rowStretch(int row ) const**

        Returns the stretch factor for row **row**.

        **See also** **setRowStretch** ().
        """
        ...

    def setColumnStretch(self, column: int, stretch: int) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#setColumnStretch

        **void QGridLayout::setColumnStretch(int column , int stretch )**

        Sets the stretch factor of column **column** to **stretch**. The first
        column is number 0.

        The stretch factor is relative to the other columns in this grid.
        Columns with a higher stretch factor take more of the available space.

        The default stretch factor is 0. If the stretch factor is 0 and no other
        column in this table can grow at all, the column may still grow.

        An alternative approach is to add spacing using **addItem** () with a
        **QSpacerItem** .

        **See also** **columnStretch** () and **setRowStretch** ().
        """
        ...

    def setRowStretch(self, row: int, stretch: int) -> None:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#setRowStretch

        **void QGridLayout::setRowStretch(int row , int stretch )**

        Sets the stretch factor of row **row** to **stretch**. The first row is
        number 0.

        The stretch factor is relative to the other rows in this grid. Rows with
        a higher stretch factor take more of the available space.

        The default stretch factor is 0. If the stretch factor is 0 and no other
        row in this table can grow at all, the row may still grow.

        **See also** **rowStretch** (), **setRowMinimumHeight** (), and
        **setColumnStretch** ().
        """
        ...

    def maximumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#maximumSize

        **[override virtual] QSize QGridLayout::maximumSize() const**

        Reimplements: **QLayout::maximumSize() const** .
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#minimumSize

        **[override virtual] QSize QGridLayout::minimumSize() const**

        Reimplements: **QLayout::minimumSize() const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qgridlayout.html#sizeHint

        **[override virtual] QSize QGridLayout::sizeHint() const**

        Reimplements: **QLayoutItem::sizeHint() const** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTextFormat(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextformat.html

    **Detailed Description**

    A QTextFormat is a generic class used for describing the format of parts of
    a **QTextDocument** . The derived classes **QTextCharFormat** ,
    **QTextBlockFormat** , **QTextListFormat** , and **QTextTableFormat**  are
    usually more useful, and describe the formatting that is applied to specific
    parts of the document.

    A format has a `FormatType` which specifies the kinds of text item it can
    format; e.g. a block of text, a list, a table, etc. A format also has
    various properties (some specific to particular format types), as described
    by the Property enum. Every property has a corresponding Property.

    The format type is given by **type** (), and the format can be tested with
    **isCharFormat** (), **isBlockFormat** (), **isListFormat** (),
    **isTableFormat** (), **isFrameFormat** (), and **isImageFormat** (). If the
    type is determined, it can be retrieved with **toCharFormat** (),
    **toBlockFormat** (), **toListFormat** (), **toTableFormat** (),
    **toFrameFormat** (), and **toImageFormat** ().

    A format's properties can be set with the **setProperty** () functions, and
    retrieved with **boolProperty** (), **intProperty** (), **doubleProperty**
    (), and **stringProperty** () as appropriate. All the property IDs used in
    the format can be retrieved with allPropertyIds(). One format can be merged
    into another using **merge** ().

    A format's object index can be set with **setObjectIndex** (), and retrieved
    with **objectIndex** (). These methods can be used to associate the format
    with a **QTextObject** . It is used to represent lists, frames, and tables
    inside the document.

    **See also** **Rich Text Processing** .
    """

    class Property(enum.IntEnum):
        ObjectIndex: QTextFormat = ...
        CssFloat: QTextFormat = ...
        LayoutDirection: QTextFormat = ...
        OutlinePen: QTextFormat = ...
        BackgroundBrush: QTextFormat = ...
        ForegroundBrush: QTextFormat = ...
        BlockAlignment: QTextFormat = ...
        BlockTopMargin: QTextFormat = ...
        BlockBottomMargin: QTextFormat = ...
        BlockLeftMargin: QTextFormat = ...
        BlockRightMargin: QTextFormat = ...
        TextIndent: QTextFormat = ...
        BlockIndent: QTextFormat = ...
        BlockNonBreakableLines: QTextFormat = ...
        BlockTrailingHorizontalRulerWidth: QTextFormat = ...
        FontPointSize: QTextFormat = ...
        FontSizeAdjustment: QTextFormat = ...
        FontSizeIncrement: QTextFormat = ...
        FontWeight: QTextFormat = ...
        FontItalic: QTextFormat = ...
        FontUnderline: QTextFormat = ...
        FontOverline: QTextFormat = ...
        FontStrikeOut: QTextFormat = ...
        FontFixedPitch: QTextFormat = ...
        FontPixelSize: QTextFormat = ...
        TextUnderlineColor: QTextFormat = ...
        TextVerticalAlignment: QTextFormat = ...
        TextOutline: QTextFormat = ...
        IsAnchor: QTextFormat = ...
        AnchorHref: QTextFormat = ...
        AnchorName: QTextFormat = ...
        ObjectType: QTextFormat = ...
        ListStyle: QTextFormat = ...
        ListIndent: QTextFormat = ...
        FrameBorder: QTextFormat = ...
        FrameMargin: QTextFormat = ...
        FramePadding: QTextFormat = ...
        FrameWidth: QTextFormat = ...
        FrameHeight: QTextFormat = ...
        TableColumns: QTextFormat = ...
        TableColumnWidthConstraints: QTextFormat = ...
        TableCellSpacing: QTextFormat = ...
        TableCellPadding: QTextFormat = ...
        TableCellRowSpan: QTextFormat = ...
        TableCellColumnSpan: QTextFormat = ...
        ImageName: QTextFormat = ...
        ImageWidth: QTextFormat = ...
        ImageHeight: QTextFormat = ...
        TextUnderlineStyle: QTextFormat = ...
        TableHeaderRowCount: QTextFormat = ...
        FullWidthSelection: QTextFormat = ...
        PageBreakPolicy: QTextFormat = ...
        TextToolTip: QTextFormat = ...
        FrameTopMargin: QTextFormat = ...
        FrameBottomMargin: QTextFormat = ...
        FrameLeftMargin: QTextFormat = ...
        FrameRightMargin: QTextFormat = ...
        FrameBorderBrush: QTextFormat = ...
        FrameBorderStyle: QTextFormat = ...
        BackgroundImageUrl: QTextFormat = ...
        TabPositions: QTextFormat = ...
        FirstFontProperty: QTextFormat = ...
        FontCapitalization: QTextFormat = ...
        FontLetterSpacing: QTextFormat = ...
        FontWordSpacing: QTextFormat = ...
        LastFontProperty: QTextFormat = ...
        TableCellTopPadding: QTextFormat = ...
        TableCellBottomPadding: QTextFormat = ...
        TableCellLeftPadding: QTextFormat = ...
        TableCellRightPadding: QTextFormat = ...
        FontStyleHint: QTextFormat = ...
        FontStyleStrategy: QTextFormat = ...
        FontKerning: QTextFormat = ...
        LineHeight: QTextFormat = ...
        LineHeightType: QTextFormat = ...
        FontHintingPreference: QTextFormat = ...
        ListNumberPrefix: QTextFormat = ...
        ListNumberSuffix: QTextFormat = ...
        FontStretch: QTextFormat = ...
        FontLetterSpacingType: QTextFormat = ...
        HeadingLevel: QTextFormat = ...
        ImageQuality: QTextFormat = ...
        FontFamilies: QTextFormat = ...
        FontStyleName: QTextFormat = ...
        BlockQuoteLevel: QTextFormat = ...
        BlockCodeLanguage: QTextFormat = ...
        BlockCodeFence: QTextFormat = ...
        BlockMarker: QTextFormat = ...
        TableBorderCollapse: QTextFormat = ...
        TableCellTopBorder: QTextFormat = ...
        TableCellBottomBorder: QTextFormat = ...
        TableCellLeftBorder: QTextFormat = ...
        TableCellRightBorder: QTextFormat = ...
        TableCellTopBorderStyle: QTextFormat = ...
        TableCellBottomBorderStyle: QTextFormat = ...
        TableCellLeftBorderStyle: QTextFormat = ...
        TableCellRightBorderStyle: QTextFormat = ...
        TableCellTopBorderBrush: QTextFormat = ...
        TableCellBottomBorderBrush: QTextFormat = ...
        TableCellLeftBorderBrush: QTextFormat = ...
        TableCellRightBorderBrush: QTextFormat = ...
        ImageTitle: QTextFormat = ...
        ImageAltText: QTextFormat = ...
        TextSuperScriptBaseline: QTextFormat = ...
        TextSubScriptBaseline: QTextFormat = ...
        TextBaselineOffset: QTextFormat = ...
        OldFontLetterSpacingType: QTextFormat = ...
        OldFontStretch: QTextFormat = ...
        OldTextUnderlineColor: QTextFormat = ...
        UserProperty: QTextFormat = ...

    class PageBreakFlag(enum.Flag):
        PageBreak_Auto: QTextFormat = ...
        PageBreak_AlwaysBefore: QTextFormat = ...
        PageBreak_AlwaysAfter: QTextFormat = ...

    class ObjectTypes(enum.IntEnum):
        NoObject: QTextFormat = ...
        ImageObject: QTextFormat = ...
        TableObject: QTextFormat = ...
        TableCellObject: QTextFormat = ...
        UserObject: QTextFormat = ...

    class FormatType(enum.IntEnum):
        InvalidFormat: QTextFormat = ...
        BlockFormat: QTextFormat = ...
        CharFormat: QTextFormat = ...
        ListFormat: QTextFormat = ...
        FrameFormat: QTextFormat = ...
        UserFormat: QTextFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#QTextFormat

        **QTextFormat::QTextFormat()**

        Creates a new text format with an `InvalidFormat`.

        **See also** **FormatType** .
        """
        ...

    @typing.overload
    def __init__(self, type: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#QTextFormat-1

        **QTextFormat::QTextFormat(int type )**

        Creates a new text format of the given **type**.

        **See also** **FormatType** .
        """
        ...

    @typing.overload
    def __init__(self, rhs: "QTextFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#QTextFormat-2

        **QTextFormat::QTextFormat(const QTextFormat & other )**

        Creates a new text format with the same attributes as the **other** text
        format.
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#QTextFormat

        **QTextFormat::QTextFormat()**

        Creates a new text format with an `InvalidFormat`.

        **See also** **FormatType** .
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isEmpty

        **[since 5.3] bool QTextFormat::isEmpty() const**

        Returns true if the format does not store any properties; false
        otherwise.

        This function was introduced in Qt 5.3.

        **See also** **propertyCount** () and **properties** ().
        """
        ...

    def swap(self, other: "QTextFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#swap

        **[since 5.0] void QTextFormat::swap(QTextFormat & other )**

        Swaps this text format with **other**. This function is very fast and
        never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def toTableCellFormat(self) -> "QTextTableCellFormat":
        """
        https://doc.qt.io/qt-6/qtextformat.html#toTableCellFormat

        **QTextTableCellFormat QTextFormat::toTableCellFormat() const**

        Returns this format as a table cell format.
        """
        ...

    def isTableCellFormat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isTableCellFormat

        **bool QTextFormat::isTableCellFormat() const**

        Returns `true` if this text format is a `TableCellFormat`; otherwise
        returns `false`.
        """
        ...

    def propertyCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextformat.html#propertyCount

        **int QTextFormat::propertyCount() const**

        Returns the number of properties stored in the format.
        """
        ...

    def setObjectType(self, atype: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#setObjectType

        **void QTextFormat::setObjectType(int type )**

        Sets the text format's object type to **type**.

        **See also** **ObjectTypes**  and **objectType** ().
        """
        ...

    def clearForeground(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#clearForeground

        **void QTextFormat::clearForeground()**

        Clears the brush used to paint the document's foreground. The default
        brush will be used.

        **See also** **foreground** (), **setForeground** (), and
        **clearBackground** ().
        """
        ...

    def foreground(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qtextformat.html#foreground

        **QBrush QTextFormat::foreground() const**

        Returns the brush used to render foreground details, such as text, frame
        outlines, and table borders.

        **See also** **setForeground** (), **clearForeground** (), and
        **background** ().
        """
        ...

    def setForeground(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#setForeground

        **void QTextFormat::setForeground(const QBrush & brush )**

        Sets the foreground brush to the specified **brush**. The foreground
        brush is mostly used to render text.

        **See also** **foreground** (), **clearForeground** (), and
        **setBackground** ().
        """
        ...

    def clearBackground(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#clearBackground

        **void QTextFormat::clearBackground()**

        Clears the brush used to paint the document's background. The default
        brush will be used.

        **See also** **background** (), **setBackground** (), and
        **clearForeground** ().
        """
        ...

    def background(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qtextformat.html#background

        **QBrush QTextFormat::background() const**

        Returns the brush used to paint the document's background.

        **See also** **setBackground** (), **clearBackground** (), and
        **foreground** ().
        """
        ...

    def setBackground(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#setBackground

        **void QTextFormat::setBackground(const QBrush & brush )**

        Sets the brush use to paint the document's background to the **brush**
        specified.

        **See also** **background** (), **clearBackground** (), and
        **setForeground** ().
        """
        ...

    def layoutDirection(self) -> QtCore.Qt.LayoutDirection:
        """
        https://doc.qt.io/qt-6/qtextformat.html#layoutDirection

        **Qt::LayoutDirection QTextFormat::layoutDirection() const**

        Returns the document's layout direction.

        **See also** **setLayoutDirection** ().
        """
        ...

    def setLayoutDirection(self, direction: QtCore.Qt.LayoutDirection) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#setLayoutDirection

        **void QTextFormat::setLayoutDirection(Qt::LayoutDirection direction )**

        Sets the document's layout direction to the specified **direction**.

        **See also** **layoutDirection** ().
        """
        ...

    def toImageFormat(self) -> "QTextImageFormat":
        """
        https://doc.qt.io/qt-6/qtextformat.html#toImageFormat

        **QTextImageFormat QTextFormat::toImageFormat() const**

        Returns this format as an image format.
        """
        ...

    def toFrameFormat(self) -> "QTextFrameFormat":
        """
        https://doc.qt.io/qt-6/qtextformat.html#toFrameFormat

        **QTextFrameFormat QTextFormat::toFrameFormat() const**

        Returns this format as a frame format.
        """
        ...

    def toTableFormat(self) -> "QTextTableFormat":
        """
        https://doc.qt.io/qt-6/qtextformat.html#toTableFormat

        **QTextTableFormat QTextFormat::toTableFormat() const**

        Returns this format as a table format.
        """
        ...

    def toListFormat(self) -> "QTextListFormat":
        """
        https://doc.qt.io/qt-6/qtextformat.html#toListFormat

        **QTextListFormat QTextFormat::toListFormat() const**

        Returns this format as a list format.
        """
        ...

    def toCharFormat(self) -> "QTextCharFormat":
        """
        https://doc.qt.io/qt-6/qtextformat.html#toCharFormat

        **QTextCharFormat QTextFormat::toCharFormat() const**

        Returns this format as a character format.
        """
        ...

    def toBlockFormat(self) -> "QTextBlockFormat":
        """
        https://doc.qt.io/qt-6/qtextformat.html#toBlockFormat

        **QTextBlockFormat QTextFormat::toBlockFormat() const**

        Returns this format as a block format.
        """
        ...

    def isTableFormat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isTableFormat

        **bool QTextFormat::isTableFormat() const**

        Returns `true` if this text format is a `TableFormat`; otherwise returns
        `false`.
        """
        ...

    def isImageFormat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isImageFormat

        **bool QTextFormat::isImageFormat() const**

        Returns `true` if this text format is an image format; otherwise returns
        `false`.
        """
        ...

    def isFrameFormat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isFrameFormat

        **bool QTextFormat::isFrameFormat() const**

        Returns `true` if this text format is a `FrameFormat`; otherwise returns
        `false`.
        """
        ...

    def isListFormat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isListFormat

        **bool QTextFormat::isListFormat() const**

        Returns `true` if this text format is a `ListFormat`; otherwise returns
        `false`.
        """
        ...

    def isBlockFormat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isBlockFormat

        **bool QTextFormat::isBlockFormat() const**

        Returns `true` if this text format is a `BlockFormat`; otherwise returns
        `false`.
        """
        ...

    def isCharFormat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isCharFormat

        **bool QTextFormat::isCharFormat() const**

        Returns `true` if this text format is a `CharFormat`; otherwise returns
        `false`.
        """
        ...

    def objectType(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextformat.html#objectType

        **int QTextFormat::objectType() const**

        Returns the text format's object type.

        **See also** **ObjectTypes**  and **setObjectType** ().
        """
        ...

    def properties(self) -> typing.Dict[int, typing.Any]:
        """
        https://doc.qt.io/qt-6/qtextformat.html#properties

        **QMap<int, QVariant> QTextFormat::properties() const**

        Returns a map with all properties of this text format.
        """
        ...

    def lengthVectorProperty(self, propertyId: int) -> typing.List[QTextLength]:
        """
        https://doc.qt.io/qt-6/qtextformat.html#lengthVectorProperty

        **QList<QTextLength> QTextFormat::lengthVectorProperty(int propertyId )
        const**

        Returns the value of the property given by **propertyId**. If the
        property isn't of QTextFormat::LengthVector type, an empty list is
        returned instead.

        **See also** **setProperty** (), **boolProperty** (), **intProperty**
        (), **doubleProperty** (), **stringProperty** (), **colorProperty** (),
        **lengthProperty** (), and **Property** .
        """
        ...

    def lengthProperty(self, propertyId: int) -> QTextLength:
        """
        https://doc.qt.io/qt-6/qtextformat.html#lengthProperty

        **QTextLength QTextFormat::lengthProperty(int propertyId ) const**

        Returns the value of the property given by **propertyId**.

        **See also** **setProperty** (), **boolProperty** (), **intProperty**
        (), **doubleProperty** (), **stringProperty** (), **colorProperty** (),
        **lengthVectorProperty** (), and **Property** .
        """
        ...

    def brushProperty(self, propertyId: int) -> QBrush:
        """
        https://doc.qt.io/qt-6/qtextformat.html#brushProperty

        **QBrush QTextFormat::brushProperty(int propertyId ) const**

        Returns the value of the property given by **propertyId** ; if the
        property isn't of **QMetaType::QBrush**  type, **Qt::NoBrush**  is
        returned instead.

        **See also** **setProperty** (), **boolProperty** (), **intProperty**
        (), **doubleProperty** (), **stringProperty** (), **lengthProperty** (),
        **lengthVectorProperty** (), and **Property** .
        """
        ...

    def penProperty(self, propertyId: int) -> QPen:
        """
        https://doc.qt.io/qt-6/qtextformat.html#penProperty

        **QPen QTextFormat::penProperty(int propertyId ) const**

        Returns the value of the property given by **propertyId** ; if the
        property isn't of **QMetaType::QPen**  type, **Qt::NoPen**  is returned
        instead.

        **See also** **setProperty** (), **boolProperty** (), **intProperty**
        (), **doubleProperty** (), **stringProperty** (), **lengthProperty** (),
        **lengthVectorProperty** (), and **Property** .
        """
        ...

    def colorProperty(self, propertyId: int) -> QColor:
        """
        https://doc.qt.io/qt-6/qtextformat.html#colorProperty

        **QColor QTextFormat::colorProperty(int propertyId ) const**

        Returns the value of the property given by **propertyId** ; if the
        property isn't of **QMetaType::QColor**  type, an invalid color is
        returned instead.

        **See also** **setProperty** (), **boolProperty** (), **intProperty**
        (), **doubleProperty** (), **stringProperty** (), **lengthProperty** (),
        **lengthVectorProperty** (), and **Property** .
        """
        ...

    def stringProperty(self, propertyId: int) -> str:
        """
        https://doc.qt.io/qt-6/qtextformat.html#stringProperty

        **QString QTextFormat::stringProperty(int propertyId ) const**

        Returns the value of the property given by **propertyId** ; if the
        property isn't of **QMetaType::QString**  type, an empty string is
        returned instead.

        **See also** **setProperty** (), **boolProperty** (), **intProperty**
        (), **doubleProperty** (), **colorProperty** (), **lengthProperty** (),
        **lengthVectorProperty** (), and **Property** .
        """
        ...

    def doubleProperty(self, propertyId: int) -> float:
        """
        https://doc.qt.io/qt-6/qtextformat.html#doubleProperty

        **qreal QTextFormat::doubleProperty(int propertyId ) const**

        Returns the value of the property specified by **propertyId**. If the
        property isn't of **QMetaType::Double**  or **QMetaType::Float**  type,
        0 is returned instead.

        **See also** **setProperty** (), **boolProperty** (), **intProperty**
        (), **stringProperty** (), **colorProperty** (), **lengthProperty** (),
        **lengthVectorProperty** (), and **Property** .
        """
        ...

    def intProperty(self, propertyId: int) -> int:
        """
        https://doc.qt.io/qt-6/qtextformat.html#intProperty

        **int QTextFormat::intProperty(int propertyId ) const**

        Returns the value of the property specified by **propertyId**. If the
        property is not of QTextFormat::Integer type, 0 is returned instead.

        **See also** **setProperty** (), **boolProperty** (), **doubleProperty**
        (), **stringProperty** (), **colorProperty** (), **lengthProperty** (),
        **lengthVectorProperty** (), and **Property** .
        """
        ...

    def boolProperty(self, propertyId: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#boolProperty

        **bool QTextFormat::boolProperty(int propertyId ) const**

        Returns the value of the property specified by **propertyId**. If the
        property isn't of QTextFormat::Bool type, false is returned instead.

        **See also** **setProperty** (), **intProperty** (), **doubleProperty**
        (), **stringProperty** (), **colorProperty** (), **lengthProperty** (),
        **lengthVectorProperty** (), and **Property** .
        """
        ...

    def hasProperty(self, propertyId: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#hasProperty

        **bool QTextFormat::hasProperty(int propertyId ) const**

        Returns `true` if the text format has a property with the given
        **propertyId** ; otherwise returns `false`.

        **See also** **properties** () and **Property** .
        """
        ...

    def clearProperty(self, propertyId: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#clearProperty

        **void QTextFormat::clearProperty(int propertyId )**

        Clears the value of the property given by **propertyId**

        **See also** **Property** .
        """
        ...

    @typing.overload
    def setProperty(
        self, propertyId: int, lengths: typing.Iterable[QTextLength]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#setProperty

        **void QTextFormat::setProperty(int propertyId , const QVariant & value
        )**

        Sets the property specified by the **propertyId** to the given
        **value**.

        **See also** **property** () and **Property** .
        """
        ...

    @typing.overload
    def setProperty(self, propertyId: int, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#setProperty-1

        **void QTextFormat::setProperty(int propertyId , const
        QList<QTextLength> & value )**

        Sets the value of the property given by **propertyId** to **value**.

        **See also** **lengthVectorProperty** () and **Property** .
        """
        ...

    def property(self, propertyId: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextformat.html#property

        **QVariant QTextFormat::property(int propertyId ) const**

        Returns the property specified by the given **propertyId**.

        **See also** **setProperty** () and **Property** .
        """
        ...

    def setObjectIndex(self, object: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#setObjectIndex

        **void QTextFormat::setObjectIndex(int index )**

        Sets the format object's object **index**.

        **See also** **objectIndex** ().
        """
        ...

    def objectIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextformat.html#objectIndex

        **int QTextFormat::objectIndex() const**

        Returns the index of the format object, or -1 if the format object is
        invalid.

        **See also** **setObjectIndex** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextformat.html#type

        **int QTextFormat::type() const**

        Returns the type of this format.

        **See also** **FormatType** .
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextformat.html#isValid

        **bool QTextFormat::isValid() const**

        Returns `true` if the format is valid (i.e. is not **InvalidFormat** );
        otherwise returns `false`.
        """
        ...

    def merge(self, other: "QTextFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextformat.html#merge

        **void QTextFormat::merge(const QTextFormat & other )**

        Merges the **other** format with this format; where there are conflicts
        the **other** format takes precedence.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QHttpPart(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhttppart.html

    **Detailed Description**

    The QHttpPart class holds a body part to be used inside a HTTP multipart
    MIME message (which is represented by the **QHttpMultiPart**  class). A
    QHttpPart consists of a header block and a data block, which are separated
    by each other by two consecutive new lines. An example for one part would
    be:

    Content-Type: text/plain
        Content-Disposition: form-data; name="text"
    here goes the body

    For setting headers, use **setHeader** () and **setRawHeader** (), which
    behave exactly like **QNetworkRequest::setHeader** () and
    **QNetworkRequest::setRawHeader** ().

    For reading small pieces of data, use **setBody** (); for larger data blocks
    like e.g. images, use **setBodyDevice** (). The latter method saves memory
    by not copying the data internally, but reading directly from the device.
    This means that the device must be opened and readable at the moment when
    the multipart message containing the body part is sent on the network via
    **QNetworkAccessManager::post** ().

    To construct a QHttpPart with a small body, consider the following snippet
    (this produces the data shown in the example above):

    **QHttpPart**  textPart;
        textPart.setHeader(**QNetworkRequest**
    ::ContentTypeHeader, **QVariant** ("text/plain"));
    textPart.setHeader(**QNetworkRequest** ::ContentDispositionHeader,
    **QVariant** ("form-data; name=\\"text\\""));
        textPart.setBody("here goes
    the body");

    To construct a QHttpPart reading from a device (e.g. a file), the following
    can be applied:

    **QHttpPart**  imagePart;
        imagePart.setHeader(**QNetworkRequest**
    ::ContentTypeHeader, **QVariant** ("image/jpeg"));
    imagePart.setHeader(**QNetworkRequest** ::ContentDispositionHeader,
    **QVariant** ("form-data; name=\\"image\\""));
    imagePart.setRawHeader("Content-ID", "my@content.id"); // add any headers
    you like via setRawHeader()
        **QFile**  *file = new **QFile**
    ("image.jpg");
        file->open(**QIODevice** ::ReadOnly);
    imagePart.setBodyDevice(file);

    Be aware that QHttpPart does not take ownership of the device when set, so
    it is the developer's responsibility to destroy it when it is not needed
    anymore. A good idea might be to set the multipart message as parent object
    for the device, as documented at the documentation for **QHttpMultiPart** .

    **See also** **QHttpMultiPart**  and **QNetworkAccessManager** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhttppart.html#QHttpPart

        **QHttpPart::QHttpPart()**

        Constructs an empty QHttpPart object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QHttpPart") -> None:
        """
        https://doc.qt.io/qt-6/qhttppart.html#QHttpPart-1

        **QHttpPart::QHttpPart(const QHttpPart & other )**

        Creates a copy of **other**.
        """
        ...

    def swap(self, other: "QHttpPart") -> None:
        """
        https://doc.qt.io/qt-6/qhttppart.html#swap

        **[since 5.0] void QHttpPart::swap(QHttpPart & other )**

        Swaps this HTTP part with **other**. This function is very fast and
        never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def setBodyDevice(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qhttppart.html#setBodyDevice

        **void QHttpPart::setBodyDevice(QIODevice * device )**

        Sets the device to read the content from to **device**. For large
        amounts of data this method should be preferred over **setBody** (),
        because the content is not copied when using this method, but read
        directly from the device. **device** must be open and readable.
        **QHttpPart**  does not take ownership of **device** , i.e. the device
        must be closed and destroyed if necessary. if **device** is sequential
        (e.g. sockets, but not files), **QNetworkAccessManager::post** () should
        be called after **device** has emitted finished(). For unsetting the
        device and using data set via **setBody** (), use "setBodyDevice(0)".

        **See also** **setBody** () and **QNetworkAccessManager::post** ().
        """
        ...

    def setBody(self, body: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qhttppart.html#setBody

        **void QHttpPart::setBody(const QByteArray & body )**

        Sets the body of this MIME part to **body**. The body set with this
        method will be used unless the device is set via **setBodyDevice** ().
        For a large amount of data (e.g. an image), use **setBodyDevice** (),
        which will not copy the data internally.

        **See also** **setBodyDevice** ().
        """
        ...

    def setRawHeader(
        self, headerName: QtCore.QByteArray, headerValue: QtCore.QByteArray
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhttppart.html#setRawHeader

        **void QHttpPart::setRawHeader(const QByteArray & headerName , const
        QByteArray & headerValue )**

        Sets the header **headerName** to be of value **headerValue**. If
        **headerName** corresponds to a known header (see
        **QNetworkRequest::KnownHeaders** ), the raw format will be parsed and
        the corresponding "cooked" header will be set as well.

        **Note:** Setting the same header twice overrides the previous setting.
        To accomplish the behaviour of multiple HTTP headers of the same name,
        you should concatenate the two values, separating them with a comma
        (",") and set one single raw header.

        **See also** **QNetworkRequest::KnownHeaders** , **setHeader** (), and
        **QNetworkRequest::setRawHeader** ().
        """
        ...

    def setHeader(
        self, header: "QNetworkRequest.KnownHeaders", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhttppart.html#setHeader

        **void QHttpPart::setHeader(QNetworkRequest::KnownHeaders header , const
        QVariant & value )**

        Sets the value of the known header **header** to be **value** ,
        overriding any previously set headers.

        **See also** **QNetworkRequest::KnownHeaders** , **setRawHeader** (),
        and **QNetworkRequest::setHeader** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QDockWidget(QWidget):
    """
    https://doc.qt.io/qt-6/qdockwidget.html

    **Detailed Description**

    QDockWidget provides the concept of dock widgets, also know as tool palettes
    or utility windows. Dock windows are secondary windows placed in the **dock
    widget area** around the **central widget**  in a **QMainWindow** .

    ![](images/mainwindow-docks.png)

    Dock windows can be moved inside their current area, moved into new areas
    and floated (e.g., undocked) by the end-user. The QDockWidget API allows the
    programmer to restrict the dock widgets ability to move, float and close, as
    well as the areas in which they can be placed.

    **Appearance**

    A QDockWidget consists of a title bar and the content area. The title bar
    displays the dock widgets **window title** , a **float** button and a
    **close** button. Depending on the state of the QDockWidget, the **float**
    and **close** buttons may be either disabled or not shown at all.

    The visual appearance of the title bar and buttons is dependent on the
    **style**  in use.

    A QDockWidget acts as a wrapper for its child widget, set with **setWidget**
    (). Custom size hints, minimum and maximum sizes and size policies should be
    implemented in the child widget. QDockWidget will respect them, adjusting
    its own constraints to include the frame and title. Size constraints should
    not be set on the QDockWidget itself, because they change depending on
    whether it is docked; a docked QDockWidget has no frame and a smaller title
    bar.

    **Note:** On macOS, if the QDockWidget has a native window handle (for
    example, if **winId** () is called on it or the child widget), then due to a
    limitation it will not be possible to drag the dock widget when undocking.
    Starting the drag will undock the dock widget, but a second drag will be
    needed to move the dock widget itself.

    **See also** **QMainWindow**  and **Dock Widgets Example** .
    """

    class DockWidgetFeature(enum.Flag):
        DockWidgetClosable: QDockWidget = ...
        DockWidgetMovable: QDockWidget = ...
        DockWidgetFloatable: QDockWidget = ...
        DockWidgetVerticalTitleBar: QDockWidget = ...
        NoDockWidgetFeatures: QDockWidget = ...

    @typing.overload
    def __init__(
        self,
        title: str,
        parent: typing.Optional[QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#QDockWidget

        **QDockWidget::QDockWidget(const QString & title , QWidget * parent =
        nullptr, Qt::WindowFlags flags = Qt::WindowFlags())**

        Constructs a QDockWidget with parent **parent** and window flags
        **flags**. The dock widget will be placed in the left dock widget area.

        The window title is set to **title**. This title is used when the
        QDockWidget is docked and undocked. It is also used in the context menu
        provided by **QMainWindow** .

        **See also** **setWindowTitle** ().
        """
        ...

    @typing.overload
    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#QDockWidget-1

        **QDockWidget::QDockWidget(QWidget * parent = nullptr, Qt::WindowFlags
        flags = Qt::WindowFlags())**

        Constructs a QDockWidget with parent **parent** and window flags
        **flags**. The dock widget will be placed in the left dock widget area.
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#event

        **[override virtual protected] bool QDockWidget::event(QEvent * event
        )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def paintEvent(self, event: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#paintEvent

        **[override virtual protected] void QDockWidget::paintEvent(QPaintEvent
        * event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def closeEvent(self, event: QtGui.QCloseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#closeEvent

        **[override virtual protected] void QDockWidget::closeEvent(QCloseEvent
        * event )**

        Reimplements: **QWidget::closeEvent** (QCloseEvent *event).
        """
        ...

    def changeEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#changeEvent

        **[override virtual protected] void QDockWidget::changeEvent(QEvent *
        event )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionDockWidget") -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#initStyleOption

        **[virtual protected] void
        QDockWidget::initStyleOption(QStyleOptionDockWidget * option ) const**

        Initialize **option** with the values from this **QDockWidget** . This
        method is useful for subclasses when they need a
        **QStyleOptionDockWidget** , but don't want to fill in all the
        information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def titleBarWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#titleBarWidget

        **QWidget *QDockWidget::titleBarWidget() const**

        Returns the custom title bar widget set on the **QDockWidget** , or
        `nullptr` if no custom title bar has been set.

        **See also** **setTitleBarWidget** ().
        """
        ...

    def setTitleBarWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#setTitleBarWidget

        **void QDockWidget::setTitleBarWidget(QWidget * widget )**

        Sets an arbitrary **widget** as the dock widget's title bar. If
        **widget** is `nullptr`, any custom title bar widget previously set on
        the dock widget is removed, but not deleted, and the default title bar
        will be used instead.

        If a title bar widget is set, **QDockWidget**  will not use native
        window decorations when it is floated.

        Here are some tips for implementing custom title bars:

        * Mouse events that are not explicitly handled by the title bar widget
        must be ignored by calling **QMouseEvent::ignore** (). These events then
        propagate to the **QDockWidget**  parent, which handles them in the
        usual manner, moving when the title bar is dragged, docking and
        undocking when it is double-clicked, etc.
          * When
        **DockWidgetVerticalTitleBar**  is set on **QDockWidget** , the title
        bar widget is repositioned accordingly. In **resizeEvent** (), the title
        bar should check what orientation it should assume:
        **QDockWidget**  *dockWidget = qobject_cast<**QDockWidget**
        \\*>(parentWidget());
            if (dockWidget->features() & **QDockWidget**
        ::DockWidgetVerticalTitleBar) {
                // I need to be vertical
            }
        else {
                // I need to be horizontal
            }

          * The title bar
        widget must have a valid **QWidget::sizeHint** () and
        **QWidget::minimumSizeHint** (). These functions should take into
        account the current orientation of the title bar.
          * It is not possible
        to remove a title bar from a dock widget. However, a similar effect can
        be achieved by setting a default constructed **QWidget**  as the title
        bar widget.

        Using **qobject_cast** () as shown above, the title bar widget has full
        access to its parent **QDockWidget** . Hence it can perform such
        operations as docking and hiding in response to user actions.

        **See also** **titleBarWidget** () and **DockWidgetVerticalTitleBar** .
        """
        ...

    def toggleViewAction(self) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#toggleViewAction

        **QAction *QDockWidget::toggleViewAction() const**

        Returns a checkable action that can be added to menus and toolbars so
        that the user can show or close this dock widget.

        The action's text is set to the dock widget's window title.

        **Note:** The action can not be used to programmatically show or hide
        the dock widget. Use the **visible**  property for that.

        **See also** **QAction::text**  and **QWidget::windowTitle** .
        """
        ...

    def isAreaAllowed(self, area: QtCore.Qt.DockWidgetArea) -> bool:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#isAreaAllowed

        **bool QDockWidget::isAreaAllowed(Qt::DockWidgetArea area ) const**

        Returns `true` if this dock widget can be placed in the given **area** ;
        otherwise returns `false`.
        """
        ...

    def allowedAreas(self) -> QtCore.Qt.DockWidgetArea:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#allowedAreas-prop

        **allowedAreas : Qt::DockWidgetAreas**

        areas where the dock widget may be placed

        The default is **Qt::AllDockWidgetAreas** .

        **Access functions:**

        Qt::DockWidgetAreas **allowedAreas** () const
        void **setAllowedAreas**
        (Qt::DockWidgetAreas **areas** )

        **Notifier signal:**

        void ****allowedAreasChanged** ** (Qt::DockWidgetAreas **allowedAreas**
        )

        **See also** **Qt::DockWidgetArea** .
        """
        ...

    def setAllowedAreas(self, areas: QtCore.Qt.DockWidgetArea) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#allowedAreas-prop

        **allowedAreas : Qt::DockWidgetAreas**

        areas where the dock widget may be placed

        The default is **Qt::AllDockWidgetAreas** .

        **Access functions:**

        Qt::DockWidgetAreas **allowedAreas** () const
        void **setAllowedAreas**
        (Qt::DockWidgetAreas **areas** )

        **Notifier signal:**

        void ****allowedAreasChanged** ** (Qt::DockWidgetAreas **allowedAreas**
        )

        **See also** **Qt::DockWidgetArea** .
        """
        ...

    def isFloating(self) -> bool:
        ...

    def setFloating(self, floating: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#floating-prop

        **floating : bool**

        This property holds whether the dock widget is floating

        A floating dock widget is presented to the user as an independent window
        "on top" of its parent **QMainWindow** , instead of being docked in the
        **QMainWindow** .

        By default, this property is `true`.

        When this property changes, the `topLevelChanged()` signal is emitted.

        **Access functions:**

        bool **isFloating** () const
        void **setFloating** (bool **floating** )

        **See also** **isWindow** () and **topLevelChanged** ().
        """
        ...

    def features(self) -> "QDockWidget.DockWidgetFeature":
        """
        https://doc.qt.io/qt-6/qdockwidget.html#features-prop

        **features : DockWidgetFeatures**

        This property holds whether the dock widget is movable, closable, and
        floatable

        By default, this property is set to a combination of
        **DockWidgetClosable** , **DockWidgetMovable**  and
        **DockWidgetFloatable** .

        **Access functions:**

        QDockWidget::DockWidgetFeatures **features** () const
        void
        **setFeatures** (QDockWidget::DockWidgetFeatures **features** )

        **Notifier signal:**

        void ****featuresChanged** ** (QDockWidget::DockWidgetFeatures
        **features** )

        **See also** **DockWidgetFeature** .
        """
        ...

    def setFeatures(self, features: "QDockWidget.DockWidgetFeature") -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#features-prop

        **features : DockWidgetFeatures**

        This property holds whether the dock widget is movable, closable, and
        floatable

        By default, this property is set to a combination of
        **DockWidgetClosable** , **DockWidgetMovable**  and
        **DockWidgetFloatable** .

        **Access functions:**

        QDockWidget::DockWidgetFeatures **features** () const
        void
        **setFeatures** (QDockWidget::DockWidgetFeatures **features** )

        **Notifier signal:**

        void ****featuresChanged** ** (QDockWidget::DockWidgetFeatures
        **features** )

        **See also** **DockWidgetFeature** .
        """
        ...

    def setWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#setWidget

        **void QDockWidget::setWidget(QWidget * widget )**

        Sets the widget for the dock widget to **widget**.

        If the dock widget is visible when **widget** is added, you must
        **show** () it explicitly.

        Note that you must add the layout of the **widget** before you call this
        function; if not, the **widget** will not be visible.

        **See also** **widget** ().
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#widget

        **QWidget *QDockWidget::widget() const**

        Returns the widget for the dock widget. This function returns zero if
        the widget has not been set.

        **See also** **setWidget** ().
        """
        ...

    @property
    def allowedAreasChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#allowedAreasChanged

        **[signal] void QDockWidget::allowedAreasChanged(Qt::DockWidgetAreas
        allowedAreas )**

        This signal is emitted when the **allowedAreas**  property changes. The
        **allowedAreas** parameter gives the new value of the property.

        **Note:** Notifier signal for property **allowedAreas** .
        """
        ...

    @property
    def dockLocationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#dockLocationChanged

        **[signal] void QDockWidget::dockLocationChanged(Qt::DockWidgetArea area
        )**

        This signal is emitted when the dock widget is moved to another dock
        **area** , or is moved to a different location in its current dock area.
        This happens when the dock widget is moved programmatically or is
        dragged to a new location by the user.
        """
        ...

    @property
    def featuresChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#featuresChanged

        **[signal] void
        QDockWidget::featuresChanged(QDockWidget::DockWidgetFeatures features
        )**

        This signal is emitted when the **features**  property changes. The
        **features** parameter gives the new value of the property.

        **Note:** Notifier signal for property **features** .
        """
        ...

    @property
    def topLevelChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#topLevelChanged

        **[signal] void QDockWidget::topLevelChanged(bool topLevel )**

        This signal is emitted when the **floating**  property changes. The
        **topLevel** parameter is true if the dock widget is now floating;
        otherwise it is false.

        **See also** **isWindow** ().
        """
        ...

    @property
    def visibilityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdockwidget.html#visibilityChanged

        **[signal] void QDockWidget::visibilityChanged(bool visible )**

        This signal is emitted when the dock widget becomes **visible** (or
        invisible). This happens when the widget is hidden or shown, as well as
        when it is docked in a tabbed dock area and its tab becomes selected or
        unselected.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtPrintSupport import *
import enum


class QPrintPreviewWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qprintpreviewwidget.html

    **Detailed Description**

    **QPrintPreviewDialog**  uses a QPrintPreviewWidget internally, and the
    purpose of QPrintPreviewWidget is to make it possible to embed the preview
    into other widgets. It also makes it possible to build a different user
    interface around it than the default one provided with
    **QPrintPreviewDialog** .

    Using QPrintPreviewWidget is straightforward:

    1. Create the QPrintPreviewWidget

    Construct the QPrintPreviewWidget either
    by passing in an existing **QPrinter**  object, or have QPrintPreviewWidget
    create a default constructed **QPrinter**  object for you.

      2. Connect the
    **paintRequested** () signal to a slot.

    When the widget needs to generate a
    set of preview pages, a **paintRequested** () signal will be emitted from
    the widget. Connect a slot to this signal, and draw onto the **QPrinter**
    passed in as a signal parameter. Call **QPrinter::newPage** (), to start a
    new page in the preview.

    **See also** **QPrinter** , **QPrintDialog** , **QPageSetupDialog** , and
    **QPrintPreviewDialog** .
    """

    class ZoomMode(enum.Enum):
        CustomZoom: QPrintPreviewWidget = ...
        FitToWidth: QPrintPreviewWidget = ...
        FitInView: QPrintPreviewWidget = ...

    class ViewMode(enum.Enum):
        SinglePageView: QPrintPreviewWidget = ...
        FacingPagesView: QPrintPreviewWidget = ...
        AllPagesView: QPrintPreviewWidget = ...

    @typing.overload
    def __init__(
        self,
        printer: QPrinter,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#QPrintPreviewWidget

        **QPrintPreviewWidget::QPrintPreviewWidget(QPrinter * printer , QWidget
        * parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags())**

        Constructs a QPrintPreviewWidget based on **printer** and with
        **parent** as the parent widget. The widget flags **flags** are passed
        on to the **QWidget**  constructor.

        **See also** **QWidget::setWindowFlags** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#QPrintPreviewWidget-1

        **QPrintPreviewWidget::QPrintPreviewWidget(QWidget * parent = nullptr,
        Qt::WindowFlags flags = Qt::WindowFlags())**

        This is an overloaded function.

        This will cause QPrintPreviewWidget to create an internal, default
        constructed **QPrinter**  object, which will be used to generate the
        preview.
        """
        ...

    def pageCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#pageCount

        **int QPrintPreviewWidget::pageCount() const**

        Returns the number of pages in the preview.
        """
        ...

    def updatePreview(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#updatePreview

        **[slot] void QPrintPreviewWidget::updatePreview()**

        This function updates the preview, which causes the **paintRequested**
        () signal to be emitted.
        """
        ...

    def setAllPagesViewMode(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setAllPagesViewMode

        **[slot] void QPrintPreviewWidget::setAllPagesViewMode()**

        This is a convenience function and is the same as calling
        `setViewMode(QPrintPreviewWidget::AllPagesView)`.
        """
        ...

    def setFacingPagesViewMode(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setFacingPagesViewMode

        **[slot] void QPrintPreviewWidget::setFacingPagesViewMode()**

        This is a convenience function and is the same as calling
        `setViewMode(QPrintPreviewWidget::FacingPagesView)`.
        """
        ...

    def setSinglePageViewMode(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setSinglePageViewMode

        **[slot] void QPrintPreviewWidget::setSinglePageViewMode()**

        This is a convenience function and is the same as calling
        `setViewMode(QPrintPreviewWidget::SinglePageView)`.
        """
        ...

    def setPortraitOrientation(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setPortraitOrientation

        **[slot] void QPrintPreviewWidget::setPortraitOrientation()**

        This is a convenience function and is the same as calling
        `setOrientation(QPageLayout::Portrait)`.
        """
        ...

    def setLandscapeOrientation(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setLandscapeOrientation

        **[slot] void QPrintPreviewWidget::setLandscapeOrientation()**

        This is a convenience function and is the same as calling
        `setOrientation(QPageLayout::Landscape)`.
        """
        ...

    def fitInView(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#fitInView

        **[slot] void QPrintPreviewWidget::fitInView()**

        This is a convenience function and is the same as calling
        `setZoomMode(QPrintPreviewWidget::FitInView)`.
        """
        ...

    def fitToWidth(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#fitToWidth

        **[slot] void QPrintPreviewWidget::fitToWidth()**

        This is a convenience function and is the same as calling
        `setZoomMode(QPrintPreviewWidget::FitToWidth)`.
        """
        ...

    def setCurrentPage(self, pageNumber: int) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setCurrentPage

        **[slot] void QPrintPreviewWidget::setCurrentPage(int page )**

        Sets the current page in the preview. This will cause the view to skip
        to the beginning of **page**.

        **See also** **currentPage** ().
        """
        ...

    def setZoomMode(self, zoomMode: "QPrintPreviewWidget.ZoomMode") -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setZoomMode

        **[slot] void
        QPrintPreviewWidget::setZoomMode(QPrintPreviewWidget::ZoomMode zoomMode
        )**

        Sets the zoom mode to **zoomMode**. The default zoom mode is
        **FitInView** .

        **See also** **zoomMode** (), **viewMode** (), and **setViewMode** ().
        """
        ...

    def setViewMode(self, viewMode: "QPrintPreviewWidget.ViewMode") -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setViewMode

        **[slot] void
        QPrintPreviewWidget::setViewMode(QPrintPreviewWidget::ViewMode mode )**

        Sets the view mode to **mode**. The default view mode is
        **SinglePageView** .

        **See also** **viewMode** ().
        """
        ...

    def setOrientation(self, orientation: QtGui.QPageLayout.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setOrientation

        **[slot] void
        QPrintPreviewWidget::setOrientation(QPageLayout::Orientation orientation
        )**

        Sets the current orientation to **orientation**. This value will be set
        on the **QPrinter**  object associated with the preview.

        **See also** **orientation** ().
        """
        ...

    def setZoomFactor(self, zoomFactor: float) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setZoomFactor

        **[slot] void QPrintPreviewWidget::setZoomFactor(qreal factor )**

        Sets the zoom factor of the view to **factor**. For example, a value of
        1.0 indicates an unscaled view, which is approximately the size the view
        will have on paper. A value of 0.5 will halve the size of the view,
        while a value of 2.0 will double the size of the view.

        **See also** **zoomFactor** ().
        """
        ...

    def zoomOut(self, factor: float = ...) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#zoomOut

        **[slot] void QPrintPreviewWidget::zoomOut(qreal factor = 1.1)**

        Zooms the current view out by **factor**. The default value for
        **factor** is 1.1, which means the view will be scaled down by 10%.
        """
        ...

    def zoomIn(self, factor: float = ...) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#zoomIn

        **[slot] void QPrintPreviewWidget::zoomIn(qreal factor = 1.1)**

        Zooms the current view in by **factor**. The default value for
        **factor** is 1.1, which means the view will be scaled up by 10%.
        """
        ...

    def print(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#print

        **[slot] void QPrintPreviewWidget::print()**

        Prints the preview to the printer associated with the preview.
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#setVisible

        **[override virtual] void QPrintPreviewWidget::setVisible(bool visible
        )**
        """
        ...

    def currentPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#currentPage

        **int QPrintPreviewWidget::currentPage() const**

        Returns the currently viewed page in the preview.

        **See also** **setCurrentPage** ().
        """
        ...

    def zoomMode(self) -> "QPrintPreviewWidget.ZoomMode":
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#zoomMode

        **QPrintPreviewWidget::ZoomMode QPrintPreviewWidget::zoomMode() const**

        Returns the current zoom mode.

        **See also** **setZoomMode** (), **viewMode** (), and **setViewMode**
        ().
        """
        ...

    def viewMode(self) -> "QPrintPreviewWidget.ViewMode":
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#viewMode

        **QPrintPreviewWidget::ViewMode QPrintPreviewWidget::viewMode() const**

        Returns the current view mode. The default view mode is
        **SinglePageView** .

        **See also** **setViewMode** ().
        """
        ...

    def orientation(self) -> QtGui.QPageLayout.Orientation:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#orientation

        **QPageLayout::Orientation QPrintPreviewWidget::orientation() const**

        Returns the current orientation of the preview. This value is obtained
        from the **QPrinter**  object associated with the preview.

        **See also** **setOrientation** ().
        """
        ...

    def zoomFactor(self) -> float:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#zoomFactor

        **qreal QPrintPreviewWidget::zoomFactor() const**

        Returns the zoom factor of the view.

        **See also** **setZoomFactor** ().
        """
        ...

    @property
    def paintRequested(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#paintRequested

        **[signal] void QPrintPreviewWidget::paintRequested(QPrinter * printer
        )**

        This signal is emitted when the preview widget needs to generate a set
        of preview pages. **printer** is the printer associated with this
        preview widget.
        """
        ...

    @property
    def previewChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprintpreviewwidget.html#previewChanged

        **[signal] void QPrintPreviewWidget::previewChanged()**

        This signal is emitted whenever the preview widget has changed some
        internal state, such as the orientation.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QMutex(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmutex.html

    **Detailed Description**

    The purpose of a QMutex is to protect an object, data structure or section
    of code so that only one thread can access it at a time (this is similar to
    the Java `synchronized` keyword). It is usually best to use a mutex with a
    **QMutexLocker**  since this makes it easy to ensure that locking and
    unlocking are performed consistently.

    For example, say there is a method that prints a message to the user on two
    lines:

    int number = 6;

        void method1()
        {
            number *= 5;
    number /= 4;
        }

        void method2()
        {
            number *= 3;
    number /= 2;
        }

    If these two methods are called in succession, the following happens:

    // method1()
        number *= 5;        // number is now 30
        number /= 4;
    // number is now 7

        // method2()
        number *= 3;        // number
    is now 21
        number /= 2;        // number is now 10

    If these two methods are called simultaneously from two threads then the
    following sequence could result:

    // Thread 1 calls method1()
        number *= 5;        // number is now 30
    // Thread 2 calls method2().
        //
        // Most likely Thread 1 has been put
    to sleep by the operating
        // system to allow Thread 2 to run.
        number
    *= 3;        // number is now 90
        number /= 2;        // number is now 45
    // Thread 1 finishes executing.
        number /= 4;        // number is now 11,
    instead of 10

    If we add a mutex, we should get the result we want:

    **QMutex**  mutex;
        int number = 6;

        void method1()
        {
    mutex.lock();
            number *= 5;
            number /= 4;
    mutex.unlock();
        }

        void method2()
        {
            mutex.lock();
    number *= 3;
            number /= 2;
            mutex.unlock();
        }

    Then only one thread can modify `number` at any given time and the result is
    correct. This is a trivial example, of course, but applies to any other case
    where things need to happen in a particular sequence.

    When you call **lock** () in a thread, other threads that try to call
    **lock** () in the same place will block until the thread that got the lock
    calls **unlock** (). A non-blocking alternative to **lock** () is
    **tryLock** ().

    QMutex is optimized to be fast in the non-contended case. It will not
    allocate memory if there is no contention on that mutex. It is constructed
    and destroyed with almost no overhead, which means it is fine to have many
    mutexes as part of other classes.

    **See also** **QRecursiveMutex** , **QMutexLocker** , **QReadWriteLock** ,
    **QSemaphore** , and **QWaitCondition** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmutex.html#QMutex

        **QMutex::QMutex()**

        Constructs a new mutex. The mutex is created in an unlocked state.
        """
        ...

    def unlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qmutex.html#unlock

        **void QMutex::unlock()**

        Unlocks the mutex. Attempting to unlock a mutex in a different thread to
        the one that locked it results in an error. Unlocking a mutex that is
        not locked results in undefined behavior.

        **See also** **lock** ().
        """
        ...

    @typing.overload
    def tryLock(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmutex.html#tryLock

        **bool QMutex::tryLock(int timeout )**

        Attempts to lock the mutex. This function returns `true` if the lock was
        obtained; otherwise it returns `false`. If another thread has locked the
        mutex, this function will wait for at most **timeout** milliseconds for
        the mutex to become available.

        Note: Passing a negative number as the **timeout** is equivalent to
        calling **lock** (), i.e. this function will wait forever until mutex
        can be locked if **timeout** is negative.

        If the lock was obtained, the mutex must be unlocked with **unlock** ()
        before another thread can successfully lock it.

        Calling this function multiple times on the same mutex from the same
        thread will cause a **dead-lock**.

        **See also** **lock** () and **unlock** ().
        """
        ...

    @typing.overload
    def tryLock(self, timeout: int) -> bool:
        """
        https://doc.qt.io/qt-6/qmutex.html#tryLock-1

        **bool QMutex::tryLock()**

        This is an overloaded function.

        Attempts to lock the mutex. This function returns `true` if the lock was
        obtained; otherwise it returns `false`.

        If the lock was obtained, the mutex must be unlocked with **unlock** ()
        before another thread can successfully lock it.

        Calling this function multiple times on the same mutex from the same
        thread will cause a **dead-lock**.

        **See also** **lock** () and **unlock** ().
        """
        ...

    def lock(self) -> None:
        """
        https://doc.qt.io/qt-6/qmutex.html#lock

        **void QMutex::lock()**

        Locks the mutex. If another thread has locked the mutex then this call
        will block until that thread has unlocked it.

        Calling this function multiple times on the same mutex from the same
        thread will cause a **dead-lock**.

        **See also** **unlock** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtOpenGL import *
import enum


class QOpenGLDebugLogger(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qopengldebuglogger.html

    **Detailed Description**

    **Introduction**

    OpenGL programming can be very error prone. Most of the time, a single
    failing call to OpenGL can cause an entire portion of an application to stop
    working, with nothing being drawn on the screen.

    The only way to be sure that no errors are being returned from the OpenGL
    implementation is checking with `glGetError` after each and every API call.
    Moreover, OpenGL errors stack up, therefore glGetError should always be used
    in a loop like this:

    GLenum error = GL_NO_ERROR;
        do {
            error = glGetError();
    if (error != GL_NO_ERROR) {
                // handle the error
            }
        }
    while (error != GL_NO_ERROR);

    If you try to clear the error stack, make sure not just keep going until
    GL_NO_ERROR is returned but also break on GL_CONTEXT_LOST as that error
    value will keep repeating.

    There are also many other information we are interested in (as application
    developers), for instance performance issues, or warnings about using
    deprecated APIs. Those kind of messages are not reported through the
    ordinary OpenGL error reporting mechanisms.

    QOpenGLDebugLogger aims at addressing these issues by providing access to
    the **OpenGL debug log**. If your OpenGL implementation supports it (by
    exposing the `GL_KHR_debug` extension), messages from the OpenGL server will
    be either logged in an internal OpenGL log, or passed in "real-time" to
    listeners as they're generated from OpenGL.

    QOpenGLDebugLogger supports both these modes of operation. Refer to the
    following sections to find out the differences between them.

    **Creating an OpenGL Debug Context**

    For efficiency reasons, OpenGL implementations are allowed not to create any
    debug output at all, unless the OpenGL context is a debug context. In order
    to create a debug context from Qt, you must set the
    **QSurfaceFormat::DebugContext**  format option on the **QSurfaceFormat**
    used to create the **QOpenGLContext**  object:

    **QSurfaceFormat**  format;
        // asks for a OpenGL 3.2 debug context using
    the Core profile
        format.setMajorVersion(3);
    format.setMinorVersion(2);
        format.setProfile(**QSurfaceFormat**
    ::CoreProfile);
        format.setOption(**QSurfaceFormat** ::DebugContext);
    **QOpenGLContext**  *context = new **QOpenGLContext** ;
    context->setFormat(format);
        context->create();

    Note that requesting a 3.2 OpenGL Core Profile is just for the example's
    purposes; this class is not tied to any specific OpenGL or OpenGL ES
    version, as it relies on the availability of the `GL_KHR_debug` extension
    (see below).

    **Creating and Initializing a QOpenGLDebugLogger**

    QOpenGLDebugLogger is a simple **QObject** -derived class. Just like all
    **QObject**  subclasses, you create an instance (and optionally specify a
    parent object), and like the other OpenGL functions in Qt you **must**
    initialize it before usage by calling **initialize** () whilst there is a
    current OpenGL context:

    **QOpenGLContext**  *ctx = **QOpenGLContext** ::currentContext();
    **QOpenGLDebugLogger**  *logger = new **QOpenGLDebugLogger** (this);
    logger->initialize(); // initializes in the current context, i.e. ctx

    Note that the `GL_KHR_debug` extension **must** be available in the context
    in order to access the messages logged by OpenGL. You can check the presence
    of this extension by calling:

    ctx->hasExtension(**QByteArrayLiteral** ("GL_KHR_debug"));

    where `ctx` is a valid **QOpenGLContext** . If the extension is not
    available, **initialize** () will return false.

    **Reading the Internal OpenGL Debug Log**

    OpenGL implementations keep an internal log of debug messages. Messages
    stored in this log can be retrieved by using the **loggedMessages** ()
    function:

    const **QList** <**QOpenGLDebugMessage** > messages =
    logger->loggedMessages();
        for (const **QOpenGLDebugMessage**  &message :
    messages)
            **qDebug** () << message;

    The internal log has a limited size; when it fills up, older messages will
    get discarded to make room for the new incoming messages. When you call
    **loggedMessages** (), the internal log will be emptied as well.

    If you want to be sure not to lose any debug message, you must use real-time
    logging instead of calling this function. However, debug messages might
    still be generated in the timespan between context creation and activation
    of real-time logging (or, in general, when the real-time logging is
    disabled).

    **Real-time logging of messages**

    It is also possible to receive a stream of debug messages from the OpenGL
    server **as they are generated** by the implementation. In order to do so,
    you need to connect a suitable slot to the **messageLogged** () signal, and
    start logging by calling **startLogging** ():

    connect(logger, &**QOpenGLDebugLogger** ::messageLogged, receiver,
    &LogHandler::handleLoggedMessage);
        logger->startLogging();

    Similarly, logging can be disabled at any time by calling the
    **stopLogging** () function.

    Real-time logging can be either asynchronous or synchronous, depending on
    the parameter passed to **startLogging** (). When logging in asynchronous
    mode (the default, as it has a very small overhead), the OpenGL
    implementation can generate messages at any time, and/or in an order which
    is different from the order of the OpenGL commands which caused those
    messages to be logged. The messages could also be generated from a thread
    that it's different from the thread the context is currently bound to. This
    is because OpenGL implementations are usually highly threaded and
    asynchronous, and therefore no warranties are made about the relative order
    and the timings of the debug messages.

    On the other hand, logging in synchronous mode has a high overhead, but the
    OpenGL implementation guarantees that all the messages caused by a certain
    command are received in order, before the command returns, and from the same
    thread the OpenGL context is bound to.

    This means that when logging in synchronous mode you will be able to run
    your OpenGL application in a debugger, put a breakpoint on a slot connected
    to the **messageLogged** () signal, and see in the backtrace the exact call
    that caused the logged message. This can be extremely useful to debug an
    OpenGL problem. Note that if OpenGL rendering is happening in another
    thread, you must force the signal/slot connection type to
    **Qt::DirectConnection**  in order to be able to see the actual backtrace.

    Refer to the **LoggingMode**  enum documentation for more information about
    logging modes.

    **Note:** When real-time logging is enabled, debug messages will **not** be
    inserted in the internal OpenGL debug log any more; messages already present
    in the internal log will not be deleted, nor they will be emitted through
    the **messageLogged** () signal. Since some messages might be generated
    before real-time logging is started (and therefore be kept in the internal
    OpenGL log), it is important to always check if it contains any message
    after calling **startLogging** ().

    **Inserting Messages in the Debug Log**

    It is possible for applications and libraries to insert custom messages in
    the debug log, for instance for marking a group of related OpenGL commands
    and therefore being then able to identify eventual messages coming from
    them.

    In order to do so, you can create a **QOpenGLDebugMessage**  object by
    calling **createApplicationMessage** () or **createThirdPartyMessage** (),
    and then inserting it into the log by calling **logMessage** ():

    **QOpenGLDebugMessage**  message =
            **QOpenGLDebugMessage**
    ::createApplicationMessage(**QStringLiteral** ("Custom message"));
    logger->logMessage(message);

    Note that OpenGL implementations have a vendor-specific limit to the length
    of the messages that can be inserted in the debug log. You can retrieve this
    length by calling the **maximumMessageLength** () method; messages longer
    than the limit will automatically get truncated.

    **Controlling the Debug Output**

    **QOpenGLDebugMessage**  is also able to apply filters to the debug
    messages, and therefore limit the amount of messages logged. You can enable
    or disable logging of messages by calling **enableMessages** () and
    **disableMessages** () respectively. By default, all messages are logged.

    It is possible to enable or disable messages by selecting them by:

    * source, type and severity (and including all ids in the selection);
      *
    id, source and type (and including all severities in the selection).

    Note that the "enabled" status for a given message is a property of the (id,
    source, type, severity) tuple; the message attributes **do not** form a
    hierarchy of any kind. You should be careful about the order of the calls to
    **enableMessages** () and **disableMessages** (), as it will change which
    messages will are enabled / disabled.

    It's not possible to filter by the message text itself; applications have to
    do that on their own (in slots connected to the **messageLogged** () signal,
    or after fetching the messages in the internal debug log through
    **loggedMessages** ()).

    In order to simplify the management of the enabled / disabled statuses,
    **QOpenGLDebugMessage**  also supports the concept of `debug groups`. A
    debug group contains the group of enabled / disabled configurations of debug
    messages. Moreover, debug groups are organized in a stack: it is possible to
    push and pop groups by calling **pushGroup** () and **popGroup** ()
    respectively. (When an OpenGL context is created, there is already a group
    in the stack).

    The **enableMessages** () and **disableMessages** () functions will modify
    the configuration in the current debug group, that is, the one at the top of
    the debug groups stack.

    When a new group is pushed onto the debug groups stack, it will inherit the
    configuration of the group that was previously on the top of the stack. Vice
    versa, popping a debug group will restore the configuration of the debug
    group that becomes the new top.

    Pushing (respectively popping) debug groups will also automatically generate
    a debug message of type **QOpenGLDebugMessage::GroupPushType**
    (respectively **GroupPopType** ).

    **See also** **QOpenGLDebugMessage** .
    """

    class LoggingMode(enum.Enum):
        AsynchronousLogging: QOpenGLDebugLogger = ...
        SynchronousLogging: QOpenGLDebugLogger = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#QOpenGLDebugLogger

        **QOpenGLDebugLogger::QOpenGLDebugLogger(QObject * parent = nullptr)**

        Constructs a new logger object with the given **parent**.

        **Note:** The object must be initialized before logging can happen.

        **See also** **initialize** ().
        """
        ...

    def stopLogging(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#stopLogging

        **[slot] void QOpenGLDebugLogger::stopLogging()**

        Stops logging messages from the OpenGL server.

        **See also** **startLogging** ().
        """
        ...

    def startLogging(self, loggingMode: "QOpenGLDebugLogger.LoggingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#startLogging

        **[slot] void
        QOpenGLDebugLogger::startLogging(QOpenGLDebugLogger::LoggingMode
        loggingMode = AsynchronousLogging)**

        Starts logging messages coming from the OpenGL server. When a new
        message is received, the signal **messageLogged** () is emitted,
        carrying the logged message as argument.

        **loggingMode** specifies whether the logging must be asynchronous (the
        default) or synchronous.

        **QOpenGLDebugLogger**  will record the values of `GL_DEBUG_OUTPUT` and
        `GL_DEBUG_OUTPUT_SYNCHRONOUS` when logging is started, and set them back
        when logging is stopped. Moreover, any user-defined OpenGL debug
        callback installed when this function is invoked will be restored when
        logging is stopped; **QOpenGLDebugLogger**  will ensure that the pre-
        existing callback will still be invoked when logging.

        **Note:** It's not possible to change the logging mode without stopping
        and starting logging again. This might change in a future version of Qt.

        **Note:** The object must be initialized before logging can happen.

        **See also** **stopLogging** () and **initialize** ().
        """
        ...

    def logMessage(self, debugMessage: QOpenGLDebugMessage) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#logMessage

        **[slot] void QOpenGLDebugLogger::logMessage(const QOpenGLDebugMessage &
        debugMessage )**

        Inserts the message **debugMessage** into the OpenGL debug log. This
        provides a way for applications or libraries to insert custom messages
        that can ease the debugging of OpenGL applications.

        **Note:** **debugMessage** must have
        **QOpenGLDebugMessage::ApplicationSource**  or
        **QOpenGLDebugMessage::ThirdPartySource**  as its source, and a valid
        type and severity, otherwise it will not be inserted into the log.

        **Note:** The object must be initialized before logging can happen.

        **See also** **initialize** ().
        """
        ...

    def loggedMessages(self) -> typing.List[QOpenGLDebugMessage]:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#loggedMessages

        **QList<QOpenGLDebugMessage> QOpenGLDebugLogger::loggedMessages()
        const**

        Reads all the available messages in the OpenGL internal debug log and
        returns them. Moreover, this function will clear the internal debug log,
        so that subsequent invocations will not return messages that were
        already returned.

        **See also** **startLogging** ().
        """
        ...

    @typing.overload
    def disableMessages(
        self,
        sources: QOpenGLDebugMessage.Source = ...,
        types: QOpenGLDebugMessage.Type = ...,
        severities: QOpenGLDebugMessage.Severity = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#disableMessages

        **void QOpenGLDebugLogger::disableMessages(QOpenGLDebugMessage::Sources
        sources = QOpenGLDebugMessage::AnySource, QOpenGLDebugMessage::Types
        types = QOpenGLDebugMessage::AnyType, QOpenGLDebugMessage::Severities
        severities = QOpenGLDebugMessage::AnySeverity)**

        Disables the logging of messages with the given **sources** , of the
        given **types** and with the given **severities** and any message id.

        The logging will be disabled in the current control group.

        **See also** **enableMessages** (), **pushGroup** (), and **popGroup**
        ().
        """
        ...

    @typing.overload
    def disableMessages(
        self,
        ids: typing.Iterable[int],
        sources: QOpenGLDebugMessage.Source = ...,
        types: QOpenGLDebugMessage.Type = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#disableMessages-1

        **void QOpenGLDebugLogger::disableMessages(const QList<GLuint> & ids ,
        QOpenGLDebugMessage::Sources sources = QOpenGLDebugMessage::AnySource,
        QOpenGLDebugMessage::Types types = QOpenGLDebugMessage::AnyType)**

        Disables the logging of messages with the given **ids** , from the given
        **sources** and of the given **types** and any severity.

        The logging will be disabled in the current control group.

        **See also** **enableMessages** (), **pushGroup** (), and **popGroup**
        ().
        """
        ...

    @typing.overload
    def enableMessages(
        self,
        sources: QOpenGLDebugMessage.Source = ...,
        types: QOpenGLDebugMessage.Type = ...,
        severities: QOpenGLDebugMessage.Severity = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#enableMessages

        **void QOpenGLDebugLogger::enableMessages(QOpenGLDebugMessage::Sources
        sources = QOpenGLDebugMessage::AnySource, QOpenGLDebugMessage::Types
        types = QOpenGLDebugMessage::AnyType, QOpenGLDebugMessage::Severities
        severities = QOpenGLDebugMessage::AnySeverity)**

        Enables the logging of messages from the given **sources** , of the
        given **types** and with the given **severities** and any message id.

        The logging will be enabled in the current control group.

        **See also** **disableMessages** (), **pushGroup** (), and **popGroup**
        ().
        """
        ...

    @typing.overload
    def enableMessages(
        self,
        ids: typing.Iterable[int],
        sources: QOpenGLDebugMessage.Source = ...,
        types: QOpenGLDebugMessage.Type = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#enableMessages-1

        **void QOpenGLDebugLogger::enableMessages(const QList<GLuint> & ids ,
        QOpenGLDebugMessage::Sources sources = QOpenGLDebugMessage::AnySource,
        QOpenGLDebugMessage::Types types = QOpenGLDebugMessage::AnyType)**

        Enables the logging of messages with the given **ids** , from the given
        **sources** and of the given **types** and any severity.

        The logging will be enabled in the current control group.

        **See also** **disableMessages** (), **pushGroup** (), and **popGroup**
        ().
        """
        ...

    def popGroup(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#popGroup

        **void QOpenGLDebugLogger::popGroup()**

        Pops the topmost debug group from the debug groups stack. If the group
        is successfully popped, OpenGL will automatically log a message with
        message, id and source matching those of the popped group, type
        **QOpenGLDebugMessage::GroupPopType**  and severity
        **QOpenGLDebugMessage::NotificationSeverity** .

        Popping a debug group will restore the message filtering settings of the
        group that becomes the top of the debug groups stack.

        **Note:** The object must be initialized before managing debug groups.

        **See also** **pushGroup** ().
        """
        ...

    def pushGroup(
        self, name: str, id: int = ..., source: QOpenGLDebugMessage.Source = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#pushGroup

        **void QOpenGLDebugLogger::pushGroup(const QString & name , GLuint id =
        0, QOpenGLDebugMessage::Source source =
        QOpenGLDebugMessage::ApplicationSource)**

        Pushes a debug group with name **name** , id **id** , and source
        **source** onto the debug groups stack. If the group is successfully
        pushed, OpenGL will automatically log a message with message **name** ,
        id **id** , source **source** , type
        **QOpenGLDebugMessage::GroupPushType**  and severity
        **QOpenGLDebugMessage::NotificationSeverity** .

        The newly pushed group will inherit the same filtering settings of the
        group that was on the top of the stack; that is, the filtering will not
        be changed by pushing a new group.

        **Note:** The **source** must either be
        **QOpenGLDebugMessage::ApplicationSource**  or
        **QOpenGLDebugMessage::ThirdPartySource** , otherwise the group will not
        be pushed.

        **Note:** The object must be initialized before managing debug groups.

        **See also** **popGroup** (), **enableMessages** (), and
        **disableMessages** ().
        """
        ...

    def maximumMessageLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#maximumMessageLength

        **qint64 QOpenGLDebugLogger::maximumMessageLength() const**

        Returns the maximum supported length, in bytes, for the text of the
        messages passed to **logMessage** (). This is also the maximum length of
        a debug group name, as pushing or popping groups will automatically log
        a message with the debug group name as the message text.

        If a message text is too long, it will be automatically truncated by
        **QOpenGLDebugLogger** .

        **Note:** Message texts are encoded in UTF-8 when they get passed to
        OpenGL, so their size in bytes does not usually match the amount of
        UTF-16 code units, as returned, for instance, by **QString::length** ().
        (It does if the message contains 7-bit ASCII only data, which is typical
        for debug messages.)
        """
        ...

    def loggingMode(self) -> "QOpenGLDebugLogger.LoggingMode":
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#loggingMode

        **QOpenGLDebugLogger::LoggingMode QOpenGLDebugLogger::loggingMode()
        const**

        Returns the logging mode of the object.

        **Note:** Getter function for property loggingMode.

        **See also** **startLogging** ().
        """
        ...

    def isLogging(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#isLogging

        **bool QOpenGLDebugLogger::isLogging() const**

        Returns `true` if this object is currently logging, false otherwise.

        **See also** **startLogging** ().
        """
        ...

    def initialize(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#initialize

        **bool QOpenGLDebugLogger::initialize()**

        Initializes the object in the current OpenGL context. The context must
        support the `GL_KHR_debug` extension for the initialization to succeed.
        The object must be initialized before any logging can happen.

        It is safe to call this function multiple times from the same context.

        This function can also be used to change the context of a previously
        initialized object; note that in this case the object must not be
        logging when you call this function.

        Returns `true` if the logger is successfully initialized; false
        otherwise.

        **See also** **QOpenGLContext** .
        """
        ...

    @property
    def messageLogged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qopengldebuglogger.html#messageLogged

        **[signal] void QOpenGLDebugLogger::messageLogged(const
        QOpenGLDebugMessage & debugMessage )**

        This signal is emitted when a debug message (wrapped by the
        **debugMessage** argument) is logged from the OpenGL server.

        Depending on the OpenGL implementation, this signal can be emitted from
        other threads than the one(s) the receiver(s) lives in, and even
        different from the thread the **QOpenGLContext**  in which this object
        has been initialized lives in. Moreover, the signal could be emitted
        from multiple threads at the same time. This is normally not a problem,
        as Qt will utilize a queued connection for cross-thread signal
        emissions, but if you force the connection type to Direct then you must
        be aware of the potential races in the slots connected to this signal.

        If logging have been started in **SynchronousLogging**  mode, OpenGL
        guarantees that this signal will be emitted from the same thread the
        **QOpenGLContext**  has been bound to, and no concurrent invocations
        will ever happen.

        **Note:** Logging must have been started, or this signal will not be
        emitted.

        **See also** **startLogging** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QDirIterator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdiriterator.html

    **Detailed Description**

    You can use QDirIterator to navigate entries of a directory one at a time.
    It is similar to **QDir::entryList** () and **QDir::entryInfoList** (), but
    because it lists entries one at a time instead of all at once, it scales
    better and is more suitable for large directories. It also supports listing
    directory contents recursively, and following symbolic links. Unlike
    **QDir::entryList** (), QDirIterator does not support sorting.

    The QDirIterator constructor takes a **QDir**  or a directory as argument.
    After construction, the iterator is located before the first directory
    entry. Here's how to iterate over all the entries sequentially:

    **QDirIterator**  it("/etc", **QDirIterator** ::Subdirectories);
        while
    (it.hasNext()) {
            **qDebug** () << it.next();

            // /etc/.
    // /etc/..
            // /etc/X11
            // /etc/X11/fs
            // ...
        }

    Here's how to find and read all files filtered by name, recursively:

    **QDirIterator**  it("/sys", **QStringList** () << "scaling_cur_freq",
    **QDir** ::NoFilter, **QDirIterator** ::Subdirectories);
        while
    (it.hasNext()) {
            **QFile**  f(it.next());
    f.open(**QIODevice** ::ReadOnly);
            **qDebug** () << f.fileName() <<
    f.readAll().trimmed().toDouble() / 1000 << "MHz";
        }

    The **next** () function returns the path to the next directory entry and
    advances the iterator. You can also call **filePath** () to get the current
    file path without advancing the iterator. The **fileName** () function
    returns only the name of the file, similar to how **QDir::entryList** ()
    works. You can also call **fileInfo** () to get a **QFileInfo**  for the
    current entry.

    Unlike Qt's container iterators, QDirIterator is uni-directional (i.e., you
    cannot iterate directories in reverse order) and does not allow random
    access.

    **See also** **QDir**  and **QDir::entryList** ().
    """

    class IteratorFlag(enum.Flag):
        NoIteratorFlags: QDirIterator = ...
        FollowSymlinks: QDirIterator = ...
        Subdirectories: QDirIterator = ...

    @typing.overload
    def __init__(self, dir: QDir, flags: "QDirIterator.IteratorFlag" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#QDirIterator

        **QDirIterator::QDirIterator(const QDir & dir ,
        QDirIterator::IteratorFlags flags = NoIteratorFlags)**

        Constructs a QDirIterator that can iterate over **dir** 's entrylist,
        using **dir** 's name filters and regular filters. You can pass options
        via **flags** to decide how the directory should be iterated.

        By default, **flags** is **NoIteratorFlags** , which provides the same
        behavior as in **QDir::entryList** ().

        The sorting in **dir** is ignored.

        **Note:** To list symlinks that point to non existing files,
        **QDir::System**  must be passed to the flags.

        **See also** **hasNext** (), **next** (), and **IteratorFlags** .
        """
        ...

    @typing.overload
    def __init__(self, path: str, flags: "QDirIterator.IteratorFlag" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#QDirIterator-1

        **QDirIterator::QDirIterator(const QString & path ,
        QDirIterator::IteratorFlags flags = NoIteratorFlags)**

        Constructs a QDirIterator that can iterate over **path**. You can pass
        options via **flags** to decide how the directory should be iterated.

        By default, **flags** is **NoIteratorFlags** , which provides the same
        behavior as in **QDir::entryList** ().

        **Note:** To list symlinks that point to non existing files,
        **QDir::System**  must be passed to the flags.

        **See also** **hasNext** (), **next** (), and **IteratorFlags** .
        """
        ...

    @typing.overload
    def __init__(
        self, path: str, filter: QDir.Filter, flags: "QDirIterator.IteratorFlag" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#QDirIterator-2

        **QDirIterator::QDirIterator(const QString & path , QDir::Filters
        filters , QDirIterator::IteratorFlags flags = NoIteratorFlags)**

        Constructs a QDirIterator that can iterate over **path** , with no name
        filtering and **filters** for entry filtering. You can pass options via
        **flags** to decide how the directory should be iterated.

        By default, **filters** is **QDir::NoFilter** , and **flags** is
        **NoIteratorFlags** , which provides the same behavior as in
        **QDir::entryList** ().

        **Note:** To list symlinks that point to non existing files,
        **QDir::System**  must be passed to the flags.

        **See also** **hasNext** (), **next** (), and **IteratorFlags** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        path: str,
        nameFilters: typing.Iterable[str],
        filters: QDir.Filter = ...,
        flags: "QDirIterator.IteratorFlag" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#QDirIterator-3

        **QDirIterator::QDirIterator(const QString & path , const QStringList &
        nameFilters , QDir::Filters filters = QDir::NoFilter,
        QDirIterator::IteratorFlags flags = NoIteratorFlags)**

        Constructs a QDirIterator that can iterate over **path** , using
        **nameFilters** and **filters**. You can pass options via **flags** to
        decide how the directory should be iterated.

        By default, **flags** is **NoIteratorFlags** , which provides the same
        behavior as **QDir::entryList** ().

        For example, the following iterator could be used to iterate over audio
        files:

        **QDirIterator**  audioFileIt(audioPath, {"*.mp3", "*.wav"}, **QDir**
        ::Files);

        **Note:** To list symlinks that point to non existing files,
        **QDir::System**  must be passed to the flags.

        **See also** **hasNext** (), **next** (), **IteratorFlags** , and
        **QDir::setNameFilters** ().
        """
        ...

    def path(self) -> str:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#path

        **QString QDirIterator::path() const**

        Returns the base directory of the iterator.
        """
        ...

    def fileInfo(self) -> "QFileInfo":
        """
        https://doc.qt.io/qt-6/qdiriterator.html#fileInfo

        **QFileInfo QDirIterator::fileInfo() const**

        Returns a **QFileInfo**  for the current directory entry.

        **See also** **filePath** () and **fileName** ().
        """
        ...

    def filePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#filePath

        **QString QDirIterator::filePath() const**

        Returns the full file path for the current directory entry.

        **See also** **fileInfo** () and **fileName** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#fileName

        **QString QDirIterator::fileName() const**

        Returns the file name for the current directory entry, without the path
        prepended.

        This function is convenient when iterating a single directory. When
        using the **QDirIterator::Subdirectories**  flag, you can use
        **filePath** () to get the full path.

        **See also** **filePath** () and **fileInfo** ().
        """
        ...

    def hasNext(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#hasNext

        **bool QDirIterator::hasNext() const**

        Returns `true` if there is at least one more entry in the directory;
        otherwise, false is returned.

        **See also** **next** (), **fileName** (), **filePath** (), and
        **fileInfo** ().
        """
        ...

    def next(self) -> str:
        """
        https://doc.qt.io/qt-6/qdiriterator.html#next

        **QString QDirIterator::next()**

        Advances the iterator to the next entry, and returns the file path of
        this new entry. If **hasNext** () returns `false`, this function does
        nothing, and returns an empty **QString** .

        You can call **fileName** () or **filePath** () to get the current entry
        file name or path, or **fileInfo** () to get a **QFileInfo**  for the
        current entry.

        **See also** **hasNext** (), **fileName** (), **filePath** (), and
        **fileInfo** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtDBus import *
import enum


class QDBusConnection(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbusconnection.html

    **Detailed Description**

    This class is the initial point in a D-Bus session. Using it, you can get
    access to remote objects, interfaces; connect remote signals to your
    object's slots; register objects, etc.

    D-Bus connections are created using the **connectToBus** () function, which
    opens a connection to the server daemon and does the initial handshaking,
    associating that connection with a name. Further attempts to connect using
    the same name will return the same connection.

    The connection is then torn down using the **disconnectFromBus** ()
    function.

    Once disconnected, calling **connectToBus** () will not reestablish a
    connection, you must create a new QDBusConnection instance.

    As a convenience for the two most common connection types, the
    **sessionBus** () and **systemBus** () functions return open connections to
    the session server daemon and the system server daemon, respectively. Those
    connections are opened when first used and are closed when the
    **QCoreApplication**  destructor is run.

    D-Bus also supports peer-to-peer connections, without the need for a bus
    server daemon. Using this facility, two applications can talk to each other
    and exchange messages. This can be achieved by passing an address to
    **connectToBus** () function, which was opened by another D-Bus application
    using **QDBusServer** .
    """

    class ConnectionCapability(enum.Flag):
        UnixFileDescriptorPassing: QDBusConnection = ...

    class UnregisterMode(enum.Enum):
        UnregisterNode: QDBusConnection = ...
        UnregisterTree: QDBusConnection = ...

    class RegisterOption(enum.Flag):
        ExportAdaptors: QDBusConnection = ...
        ExportScriptableSlots: QDBusConnection = ...
        ExportScriptableSignals: QDBusConnection = ...
        ExportScriptableProperties: QDBusConnection = ...
        ExportScriptableInvokables: QDBusConnection = ...
        ExportScriptableContents: QDBusConnection = ...
        ExportNonScriptableSlots: QDBusConnection = ...
        ExportNonScriptableSignals: QDBusConnection = ...
        ExportNonScriptableProperties: QDBusConnection = ...
        ExportNonScriptableInvokables: QDBusConnection = ...
        ExportNonScriptableContents: QDBusConnection = ...
        ExportAllSlots: QDBusConnection = ...
        ExportAllSignals: QDBusConnection = ...
        ExportAllProperties: QDBusConnection = ...
        ExportAllInvokables: QDBusConnection = ...
        ExportAllContents: QDBusConnection = ...
        ExportAllSignal: QDBusConnection = ...
        ExportChildObjects: QDBusConnection = ...

    class BusType(enum.Enum):
        SessionBus: QDBusConnection = ...
        SystemBus: QDBusConnection = ...
        ActivationBus: QDBusConnection = ...

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#QDBusConnection

        **QDBusConnection::QDBusConnection(const QString & name )**

        Creates a QDBusConnection object attached to the connection with name
        **name**.

        This does not open the connection. You have to call **connectToBus** ()
        to open it.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDBusConnection") -> None:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#QDBusConnection-1

        **QDBusConnection::QDBusConnection(const QDBusConnection & other )**

        Creates a copy of the **other** connection.
        """
        ...

    def swap(self, other: "QDBusConnection") -> None:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#swap

        **void QDBusConnection::swap(QDBusConnection & other )**

        Swaps this **QDBusConnection**  instance with **other**.
        """
        ...

    @staticmethod
    def systemBus() -> "QDBusConnection":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#systemBus

        **[static] QDBusConnection QDBusConnection::systemBus()**

        Returns a **QDBusConnection**  object opened with the system bus. The
        object reference returned by this function is valid until the
        **QCoreApplication** 's destructor is run, when the connection will be
        closed and the object, deleted.
        """
        ...

    @staticmethod
    def sessionBus() -> "QDBusConnection":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#sessionBus

        **[static] QDBusConnection QDBusConnection::sessionBus()**

        Returns a **QDBusConnection**  object opened with the session bus. The
        object reference returned by this function is valid until the
        application terminates, at which point the connection will be closed and
        the object deleted.
        """
        ...

    @staticmethod
    def localMachineId() -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#localMachineId

        **[static] QByteArray QDBusConnection::localMachineId()**

        Returns the local machine ID as known to the D-Bus system. Each node or
        host that runs D-Bus has a unique identifier that can be used to
        distinguish it from other hosts if they are sharing resources like the
        filesystem.

        Note that the local machine ID is not guaranteed to be persistent across
        boots of the system, so this identifier should not be stored in
        persistent storage (like the filesystem). It is guaranteed to remain
        constant only during the lifetime of this boot session.
        """
        ...

    @staticmethod
    def disconnectFromPeer(name: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#disconnectFromPeer

        **[static] void QDBusConnection::disconnectFromPeer(const QString & name
        )**

        Closes the peer connection of name **name**.

        Note that if there are still **QDBusConnection**  objects associated
        with the same connection, the connection will not be closed until all
        references are dropped. However, no further references can be created
        using the **QDBusConnection**  constructor.
        """
        ...

    @staticmethod
    def disconnectFromBus(name: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#disconnectFromBus

        **[static] void QDBusConnection::disconnectFromBus(const QString & name
        )**

        Closes the bus connection of name **name**.

        Note that if there are still **QDBusConnection**  objects associated
        with the same connection, the connection will not be closed until all
        references are dropped. However, no further references can be created
        using the **QDBusConnection**  constructor.
        """
        ...

    @staticmethod
    def connectToPeer(address: str, name: str) -> "QDBusConnection":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#connectToPeer

        **[static] QDBusConnection QDBusConnection::connectToPeer(const QString
        & address , const QString & name )**

        Opens a peer-to-peer connection on address **address** and associate
        with it the connection name **name**. Returns a **QDBusConnection**
        object associated with that connection.
        """
        ...

    @typing.overload
    @staticmethod
    def connectToBus(type: "QDBusConnection.BusType", name: str) -> "QDBusConnection":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#connectToBus

        **[static] QDBusConnection
        QDBusConnection::connectToBus(QDBusConnection::BusType type , const
        QString & name )**

        Opens a connection of type **type** to one of the known busses and
        associate with it the connection name **name**. Returns a
        **QDBusConnection**  object associated with that connection.
        """
        ...

    @typing.overload
    @staticmethod
    def connectToBus(address: str, name: str) -> "QDBusConnection":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#connectToBus-1

        **[static] QDBusConnection QDBusConnection::connectToBus(const QString &
        address , const QString & name )**

        Opens a connection to a private bus on address **address** and associate
        with it the connection name **name**. Returns a **QDBusConnection**
        object associated with that connection.
        """
        ...

    def interface(self) -> "QDBusConnectionInterface":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#interface

        **QDBusConnectionInterface *QDBusConnection::interface() const**

        Returns a **QDBusConnectionInterface**  object that represents the D-Bus
        server interface on this connection.
        """
        ...

    def unregisterService(self, serviceName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#unregisterService

        **bool QDBusConnection::unregisterService(const QString & serviceName
        )**

        Unregisters the service **serviceName** that was previously registered
        with **registerService** () and returns `true` if it succeeded.

        **See also** **registerService** () and
        **QDBusConnectionInterface::unregisterService** ().
        """
        ...

    def registerService(self, serviceName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#registerService

        **bool QDBusConnection::registerService(const QString & serviceName )**

        Attempts to register the **serviceName** on the D-Bus server and returns
        `true` if the registration succeeded. The registration will fail if the
        name is already registered by another application.

        **See also** **unregisterService** () and
        **QDBusConnectionInterface::registerService** ().
        """
        ...

    def objectRegisteredAt(self, path: str) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#objectRegisteredAt

        **QObject *QDBusConnection::objectRegisteredAt(const QString & path )
        const**

        Return the object that was registered with the **registerObject** () at
        the object path given by **path**.
        """
        ...

    def unregisterObject(
        self, path: str, mode: "QDBusConnection.UnregisterMode" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#unregisterObject

        **void QDBusConnection::unregisterObject(const QString & path ,
        QDBusConnection::UnregisterMode mode = UnregisterNode)**

        Unregisters an object that was registered with the **registerObject** ()
        at the object path given by **path** and, if **mode** is
        **QDBusConnection::UnregisterTree** , all of its sub-objects too.

        Note that you cannot unregister objects that were not registered with
        **registerObject** ().
        """
        ...

    @typing.overload
    def registerObject(
        self,
        path: str,
        object: QtCore.QObject,
        options: "QDBusConnection.RegisterOption" = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#registerObject

        **bool QDBusConnection::registerObject(const QString & path , QObject *
        object , QDBusConnection::RegisterOptions options = ExportAdaptors)**

        Registers the object **object** at path **path** and returns `true` if
        the registration was successful. The **options** parameter specifies how
        much of the object **object** will be exposed through D-Bus.

        This function does not replace existing objects: if there is already an
        object registered at path **path** , this function will return false.
        Use **unregisterObject** () to unregister it first.

        The **ExportChildObjects**  flag exports child objects on D-Bus based on
        the path of the registered objects and the **QObject::objectName**  of
        the child. Therefore, it is important for the child object to have an
        object name.

        You cannot register an object as a child object of an object that was
        registered with **ExportChildObjects** .
        """
        ...

    @typing.overload
    def registerObject(
        self,
        path: str,
        interface: str,
        object: QtCore.QObject,
        options: "QDBusConnection.RegisterOption" = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#registerObject-1

        **[since 5.5] bool QDBusConnection::registerObject(const QString & path
        , const QString & interface , QObject * object ,
        QDBusConnection::RegisterOptions options = ExportAdaptors)**

        This is an overloaded function.

        Registers the object **object** at path **path** with interface name
        **interface** and returns `true` if the registration was successful. The
        **options** parameter specifies how much of the object **object** will
        be exposed through D-Bus.

        This function does not replace existing objects: if there is already an
        object registered at path **path** , this function will return false.
        Use **unregisterObject** () to unregister it first.

        The **ExportChildObjects**  flag exports child objects on D-Bus based on
        the path of the registered objects and the **QObject::objectName**  of
        the child. Therefore, it is important for the child object to have an
        object name.

        You cannot register an object as a child object of an object that was
        registered with **ExportChildObjects** .

        This function was introduced in Qt 5.5.
        """
        ...

    @typing.overload
    def disconnect(
        self, service: str, path: str, interface: str, name: str, slot: PYQT_SLOT
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#disconnect

        **bool QDBusConnection::disconnect(const QString & service , const
        QString & path , const QString & interface , const QString & name ,
        QObject * receiver , const char * slot )**

        Disconnects the signal specified by the **service** , **path** ,
        **interface** and **name** parameters from the slot **slot** in object
        **receiver**. The arguments must be the same as passed to the
        **connect** () function.

        Returns `true` if the disconnection was successful.
        """
        ...

    @typing.overload
    def disconnect(
        self,
        service: str,
        path: str,
        interface: str,
        name: str,
        signature: str,
        slot: PYQT_SLOT,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#disconnect-1

        **bool QDBusConnection::disconnect(const QString & service , const
        QString & path , const QString & interface , const QString & name ,
        const QString & signature , QObject * receiver , const char * slot )**

        This is an overloaded function.

        Disconnects the signal specified by the **service** , **path** ,
        **interface** , **name** , and **signature** parameters from the slot
        **slot** in object **receiver**. The arguments must be the same as
        passed to the **connect** () function.

        Returns `true` if the disconnection was successful.
        """
        ...

    @typing.overload
    def disconnect(
        self,
        service: str,
        path: str,
        interface: str,
        name: str,
        argumentMatch: typing.Iterable[str],
        signature: str,
        slot: PYQT_SLOT,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#disconnect-2

        **bool QDBusConnection::disconnect(const QString & service , const
        QString & path , const QString & interface , const QString & name ,
        const QStringList & argumentMatch , const QString & signature , QObject
        * receiver , const char * slot )**

        This is an overloaded function.

        Disconnects the signal specified by the **service** , **path** ,
        **interface** , **name** , **argumentMatch** , and **signature**
        parameters from the slot **slot** in object **receiver**. The arguments
        must be the same as passed to the **connect** () function.

        Returns `true` if the disconnection was successful.
        """
        ...

    @typing.overload
    def connect(
        self, service: str, path: str, interface: str, name: str, slot: PYQT_SLOT
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#connect

        **bool QDBusConnection::connect(const QString & service , const QString
        & path , const QString & interface , const QString & name , QObject *
        receiver , const char * slot )**

        Connects the signal specified by the **service** , **path** ,
        **interface** and **name** parameters to the slot **slot** in object
        **receiver**. The arguments **service** and **path** can be empty,
        denoting a connection to any signal of the ( **interface** , **name** )
        pair, from any remote application.

        Returns `true` if the connection was successful.

        **Warning:** The signal will only be delivered to the slot if the
        parameters match. This verification can be done only when the signal is
        received, not at connection time.
        """
        ...

    @typing.overload
    def connect(
        self,
        service: str,
        path: str,
        interface: str,
        name: str,
        signature: str,
        slot: PYQT_SLOT,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#connect-1

        **bool QDBusConnection::connect(const QString & service , const QString
        & path , const QString & interface , const QString & name , const
        QString & signature , QObject * receiver , const char * slot )**

        This is an overloaded function.

        Connects the signal to the slot **slot** in object **receiver**. Unlike
        the previous connect() overload, this function allows one to specify the
        parameter signature to be connected using the **signature** variable.
        The function will then verify that this signature can be delivered to
        the slot specified by **slot** and return false otherwise.

        Returns `true` if the connection was successful.

        **Note:** This function verifies that the signal signature matches the
        slot's parameters, but it does not verify that the actual signal exists
        with the given signature in the remote service.
        """
        ...

    @typing.overload
    def connect(
        self,
        service: str,
        path: str,
        interface: str,
        name: str,
        argumentMatch: typing.Iterable[str],
        signature: str,
        slot: PYQT_SLOT,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#connect-2

        **bool QDBusConnection::connect(const QString & service , const QString
        & path , const QString & interface , const QString & name , const
        QStringList & argumentMatch , const QString & signature , QObject *
        receiver , const char * slot )**

        This is an overloaded function.

        Connects the signal to the slot **slot** in object **receiver**. Unlike
        the previous connect() overload, this function allows one to specify the
        parameter signature to be connected using the **signature** variable.
        The function will then verify that this signature can be delivered to
        the slot specified by **slot** and return false otherwise.

        The **argumentMatch** parameter lists the string parameters to be
        matched, in sequential order. Note that, to match an empty string, you
        need to pass a **QString**  that is empty but not null (i.e.,
        **QString** ("")). A null **QString**  skips matching at that position.

        Returns `true` if the connection was successful.

        **Note:** This function verifies that the signal signature matches the
        slot's parameters, but it does not verify that the actual signal exists
        with the given signature in the remote service.
        """
        ...

    def asyncCall(
        self, message: "QDBusMessage", timeout: int = ...
    ) -> "QDBusPendingCall":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#asyncCall

        **QDBusPendingCall QDBusConnection::asyncCall(const QDBusMessage &
        message , int timeout = -1) const**

        Sends the **message** over this connection and returns immediately. This
        function is suitable for method calls only. It returns an object of type
        **QDBusPendingCall**  which can be used to track the status of the
        reply.

        If no reply is received within **timeout** milliseconds, an automatic
        error will be delivered indicating the expiration of the call. The
        default **timeout** is -1, which will be replaced with an
        implementation-defined value that is suitable for inter-process
        communications (generally, 25 seconds). This timeout is also the upper
        limit for waiting in QDBusPendingCall::waitForFinished().

        See the **QDBusInterface::asyncCall** () function for a more friendly
        way of placing calls.
        """
        ...

    def call(
        self, message: "QDBusMessage", mode: QDBus.CallMode = ..., timeout: int = ...
    ) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#call

        **QDBusMessage QDBusConnection::call(const QDBusMessage & message ,
        QDBus::CallMode mode = QDBus::Block, int timeout = -1) const**

        Sends the **message** over this connection and blocks, waiting for a
        reply, for at most **timeout** milliseconds. This function is suitable
        for method calls only. It returns the reply message as its return value,
        which will be either of type **QDBusMessage::ReplyMessage**  or
        **QDBusMessage::ErrorMessage** .

        If no reply is received within **timeout** milliseconds, an automatic
        error will be delivered indicating the expiration of the call. The
        default **timeout** is -1, which will be replaced with an
        implementation-defined value that is suitable for inter-process
        communications (generally, 25 seconds).

        See the **QDBusInterface::call** () function for a more friendly way of
        placing calls.

        **Warning:** If **mode** is **QDBus::BlockWithGui** , this function will
        reenter the Qt event loop in order to wait for the reply. During the
        wait, it may deliver signals and other method calls to your application.
        Therefore, it must be prepared to handle a reentrancy whenever a call is
        placed with call().
        """
        ...

    def callWithCallback(
        self,
        message: "QDBusMessage",
        returnMethod: PYQT_SLOT,
        errorMethod: PYQT_SLOT,
        timeout: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#callWithCallback

        **bool QDBusConnection::callWithCallback(const QDBusMessage & message ,
        QObject * receiver , const char * returnMethod , const char *
        errorMethod , int timeout = -1) const**

        Sends the **message** over this connection and returns immediately. When
        the reply is received, the method **returnMethod** is called in the
        **receiver** object. If an error occurs, the method **errorMethod** will
        be called instead.

        If no reply is received within **timeout** milliseconds, an automatic
        error will be delivered indicating the expiration of the call. The
        default **timeout** is -1, which will be replaced with an
        implementation-defined value that is suitable for inter-process
        communications (generally, 25 seconds).

        This function is suitable for method calls only. It is guaranteed that
        the slot will be called exactly once with the reply, as long as the
        parameter types match and no error occurs.

        Returns `true` if the message was sent, or false if the message could
        not be sent.
        """
        ...

    def send(self, message: "QDBusMessage") -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#send

        **bool QDBusConnection::send(const QDBusMessage & message ) const**

        Sends the **message** over this connection, without waiting for a reply.
        This is suitable for errors, signals, and return values as well as calls
        whose return values are not necessary.

        Returns `true` if the message was queued successfully, false otherwise.
        """
        ...

    def connectionCapabilities(self) -> "QDBusConnection.ConnectionCapability":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#connectionCapabilities

        **QDBusConnection::ConnectionCapabilities
        QDBusConnection::connectionCapabilities() const**

        Returns the capabilities of this connection as negotiated with the bus
        server or peer. If this **QDBusConnection**  is not connected, this
        function returns no capabilities.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#name

        **QString QDBusConnection::name() const**

        Returns the connection name for this connection, as given as the name
        parameter to **connectToBus** ().

        The connection name can be used to uniquely identify actual underlying
        connections to buses. Copies made from a single connection will always
        implicitly share the underlying connection, and hence will have the same
        connection name.

        Inversely, two connections having different connection names will always
        either be connected to different buses, or have a different unique name
        (as returned by **baseService** ()) on that bus.

        **See also** **connectToBus** () and **disconnectFromBus** ().
        """
        ...

    def lastError(self) -> "QDBusError":
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#lastError

        **QDBusError QDBusConnection::lastError() const**

        Returns the last error that happened in this connection.

        This function is provided for low-level code. If you're using
        **QDBusInterface::call** (), error codes are reported by its return
        value.

        **See also** **QDBusInterface**  and **QDBusMessage** .
        """
        ...

    def baseService(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#baseService

        **QString QDBusConnection::baseService() const**

        Returns the unique connection name for this connection, if this
        **QDBusConnection**  object is connected, or an empty **QString**
        otherwise.

        A Unique Connection Name is a string in the form ":x.xxx" (where x are
        decimal digits) that is assigned by the D-Bus server daemon upon
        connection. It uniquely identifies this client in the bus.

        This function returns an empty **QString**  for peer-to-peer
        connections.
        """
        ...

    def isConnected(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusconnection.html#isConnected

        **bool QDBusConnection::isConnected() const**

        Returns `true` if this **QDBusConnection**  object is connected.
        """
        ...
